package com.example.kurama.aprieta;

import android.annotation.SuppressLint;
import android.content.DialogInterface;
import android.content.Intent;

import android.support.annotation.NonNull;
import android.support.v4.graphics.ColorUtils;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageButton;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;

public class AllChallengeListActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private RecyclerView challengeList;
    private ImageButton addChallenge;

    private FirebaseAuth mAuth;
    private DatabaseReference UserRef, ChallengeRef;
    private String currentUserID;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_challenges_list);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users").child(currentUserID);
        ChallengeRef = FirebaseDatabase.getInstance().getReference().child("Challenges");

        mToolbar =  findViewById(R.id.challenges_list_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.globar_challege_title);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        addChallenge = findViewById(R.id.addChallenges);

        challengeList = (RecyclerView) findViewById(R.id.challenges_list);
        challengeList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        challengeList.setLayoutManager(linearLayoutManager);

        addChallenge.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                final CharSequence[] item ={"Crear retos manualmente","Creador de retos inteligente"};

                AlertDialog.Builder builder = new AlertDialog.Builder(AllChallengeListActivity.this);
                builder.setTitle("Crear reto");
                builder.setItems(item, new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int i) {
                        if(item[i].equals("Crear retos manualmente")){
                            SendUserToManualChallengeActivity();
                        }else if(item[i].equals("Creador de retos inteligente")){
                            SendUserToSmartChallengeActivity();
                        }
                    }
                });
                builder.show();
            }
        });

        searchOwnChallenges();


    }

    private void searchOwnChallenges() {
        Query searchOwnChallenges = ChallengeRef.orderByChild("rate");

        FirebaseRecyclerOptions<FindOwnChallenges> options = new FirebaseRecyclerOptions.Builder<FindOwnChallenges>().setQuery(searchOwnChallenges, FindOwnChallenges.class).build();
        final FirebaseRecyclerAdapter<FindOwnChallenges, AllChallengeListActivity.FindOwnChallengesViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindOwnChallenges, AllChallengeListActivity.FindOwnChallengesViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final AllChallengeListActivity.FindOwnChallengesViewHolder holder, int position, @NonNull final FindOwnChallenges model) {
                final String challengeKey = getRef(position).getKey();

                ChallengeRef.child(challengeKey).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.child("Participants").child(currentUserID).child("bouldersDone").exists()){
                            holder.bouldersDone.setText(dataSnapshot.child("Participants").child(currentUserID).child("bouldersDone").getValue().toString()+" bloques completados de "+dataSnapshot.child("Boulders").getChildrenCount());
                            if(dataSnapshot.child("Participants").child(currentUserID).child("bouldersDone").getValue().toString().equals(String.valueOf(dataSnapshot.child("Boulders").getChildrenCount()))){
                                holder.layout.setBackgroundColor(ColorUtils.XYZToColor(57,69,54));
                                holder.bouldersDone.setText("Reto completado!! "+ "Bloques, " + dataSnapshot.child("Participants").child(currentUserID).child("bouldersDone").getValue().toString()+" de "+dataSnapshot.child("Boulders").getChildrenCount());
                            }
                        }else{
                            holder.bouldersDone.setText("Entra en el reto para participar!!");
                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });

                holder.difficulty.setText(model.getDifficulty());
                holder.username.setText("Reto creado por "+model.getUsername());
                holder.mView.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        Intent challengeProfileIntent = new Intent(AllChallengeListActivity.this, ChallengeProfileActivity.class);
                        challengeProfileIntent.putExtra("ChallengeKey", challengeKey);
                        startActivity(challengeProfileIntent);
                        finish();
                    }
                });

            }

            @NonNull
            @Override
            public AllChallengeListActivity.FindOwnChallengesViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.all_challenges_display_layout, parent, false);
                AllChallengeListActivity.FindOwnChallengesViewHolder viewHolder = new AllChallengeListActivity.FindOwnChallengesViewHolder(view);
                return viewHolder;
            }
        };
        challengeList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();



    }

    public static class FindOwnChallengesViewHolder extends RecyclerView.ViewHolder{

        TextView username, bouldersDone, difficulty;
        RelativeLayout layout;
        View mView;
        public FindOwnChallengesViewHolder(View itemView) {
            super(itemView);
            mView = itemView;

            username=mView.findViewById(R.id.all_challenge_creator);
            bouldersDone=mView.findViewById(R.id.bouldersDone_in_challenge);
            difficulty=mView.findViewById(R.id.challenge_difficulty);
            layout = mView.findViewById(R.id.layoutBackground);
        }



    }


    private void SendUserToManualChallengeActivity() {
        Intent friendListIntent = new Intent(AllChallengeListActivity.this, ManualChallengeActivity.class);
        startActivity(friendListIntent);
        finish();
    }

    private void SendUserToSmartChallengeActivity() {
        Intent friendListIntent = new Intent(AllChallengeListActivity.this, SmartChallengeActivity.class);
        startActivity(friendListIntent);
        finish();
    }
}
