package com.example.kurama.aprieta;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.location.Address;
import android.location.Geocoder;
import android.net.Uri;
import android.provider.MediaStore;
import android.support.annotation.NonNull;
import android.support.v4.app.ActivityCompat;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.StorageReference;
import com.google.firebase.storage.UploadTask;
import com.theartofdev.edmodo.cropper.CropImage;
import com.theartofdev.edmodo.cropper.CropImageView;

import java.io.IOException;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import static android.Manifest.permission.WRITE_EXTERNAL_STORAGE;


public class BoulderActivity extends AppCompatActivity implements AdapterView.OnItemSelectedListener {
    private Toolbar mToolbar;
    private ProgressDialog loadingBar;

    private Uri ImageUri;

    private Spinner gradeBox, heightBox;
    private EditText boulderName, boulderDescription;
    private ImageButton boulderImage;
    private Button saveBoulder;
    private TextView Latitude, Longitude, Location;

    private DatabaseReference UserRef, BoulderRef;
    private FirebaseAuth mAuth;
    private StorageReference boulderImageStorage;
    private String currentUserID, height, grade, name, latitude, longitude, description, saveCurrentDate, saveCurrentTime, boulderRandomName,downloadURL1, location, storage;

    private final static int Gallery_Pick = 0;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_boulder);

        requestPermission();
        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");
        BoulderRef = FirebaseDatabase.getInstance().getReference().child("Boulders");
        boulderImageStorage = FirebaseStorage.getInstance().getReference();

        latitude = getIntent().getExtras().get("Latitude").toString();
        longitude = getIntent().getExtras().get("Longitude").toString();

        mToolbar = (Toolbar) findViewById(R.id.boulder_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.add_boulder_title);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        loadingBar = new ProgressDialog(this);

        boulderName = findViewById(R.id.boulderName);
        boulderDescription = findViewById(R.id.boulderDescription);
        boulderImage = findViewById(R.id.addBoulderImage);
        saveBoulder = findViewById(R.id.save_boulder);

        Latitude = findViewById(R.id.boulderLatitude1);
        Longitude = findViewById(R.id.boulderLongitude1);
        Location = findViewById(R.id.boulderLocation);

        DecimalFormat df = new DecimalFormat("#.#######");
        df.setRoundingMode(RoundingMode.CEILING);
        Double la = Double.parseDouble(latitude);
        Double lo = Double.parseDouble(longitude);
        Latitude.setText(df.format(la));
        Longitude.setText(df.format(lo));

        gradeBox = findViewById(R.id.gradeBox);
        ArrayAdapter<CharSequence> adapter = ArrayAdapter.createFromResource(this, R.array.grades, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        gradeBox.setAdapter(adapter);
        gradeBox.setOnItemSelectedListener(this);

        heightBox = findViewById(R.id.heightBox);
        ArrayAdapter<CharSequence> adapter1 = ArrayAdapter.createFromResource(this, R.array.height, android.R.layout.simple_spinner_item);
        adapter1.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        heightBox.setAdapter(adapter1);
        heightBox.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            @Override
            public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
                height = parent.getItemAtPosition(position).toString();
            }

            @Override
            public void onNothingSelected(AdapterView<?> parent) {

            }
        });


        location = getAddress(this, Double.parseDouble(latitude), Double.parseDouble(longitude));
        Location.setText(location);
        boulderImage.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                openGallery();
            }

        });

        saveBoulder.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                ValidateInfo();
            }
        });
    }

    private void requestPermission(){
        ActivityCompat.requestPermissions(this, new String[]{WRITE_EXTERNAL_STORAGE},1);
    }
    public String getAddress(Context context, double lat, double lng) {
        Geocoder geocoder = new Geocoder(context, Locale.getDefault());
        try {
            if(!geocoder.getFromLocation(lat, lng, 1).isEmpty()) {
                List<Address> addresses = geocoder.getFromLocation(lat, lng, 1);
                Address obj = addresses.get(0);
                String add;
                add = obj.getCountryName() + ", " + obj.getSubAdminArea() + ", " + obj.getLocality();
                add = add.replace(", null", "");
                System.out.println(add);
                return add;
            }else{
                location = "Sitio desconocido";
                return location;
            }
        } catch (IOException e) {
            e.printStackTrace();
            Toast.makeText(this, e.getMessage(), Toast.LENGTH_SHORT).show();
            return null;
        }
    }




    private void ValidateInfo() {
        name = boulderName.getText().toString();
        description = boulderDescription.getText().toString();

        if(name.equals("") || latitude.equals("") || longitude.equals("") || description.equals("")){
            Toast.makeText(this, R.string.boulder_fill_noty, Toast.LENGTH_SHORT).show();
        }else{
            StoringImage();
        }

    }

    private void StoringImage() {
        Calendar date = Calendar.getInstance();
        SimpleDateFormat currentDate = new SimpleDateFormat("dd-MM-yyyy");
        saveCurrentDate = currentDate.format(date.getTime());

        Calendar time = Calendar.getInstance();
        SimpleDateFormat currentTime = new SimpleDateFormat("HH:mm:ss");
        saveCurrentTime = currentTime.format(time.getTime());

        boulderRandomName = saveCurrentDate + saveCurrentTime;

        boulderRandomName = boulderRandomName.replaceAll("\\-", "");

        boulderRandomName = boulderRandomName.replaceAll("\\:", "");
        if(ImageUri==null){
            Toast.makeText(this, R.string.boulder_fill_noty, Toast.LENGTH_SHORT).show();
        }else {
            loadingBar.setTitle(R.string.boulder_loading);
            loadingBar.show();
            StorageReference filePath1 = boulderImageStorage.child("BoulderImage").child(ImageUri.getLastPathSegment() + boulderRandomName + ".jpg");

            filePath1.putFile(ImageUri).addOnCompleteListener(new OnCompleteListener<UploadTask.TaskSnapshot>() {
                @Override
                public void onComplete(@NonNull Task<UploadTask.TaskSnapshot> task) {
                    if (task.isSuccessful()) {
                        downloadURL1 = task.getResult().getDownloadUrl().toString();
                        storage = task.getResult().getStorage().toString();
                        Toast.makeText(BoulderActivity.this, R.string.boulder_generated_noty, Toast.LENGTH_SHORT).show();
                        StoreInfoBoulder();

                    } else {
                        String message = task.getException().getMessage();
                        Toast.makeText(BoulderActivity.this, "Error:" + message, Toast.LENGTH_SHORT).show();
                    }
                }
            });
        }

    }

    private void StoreInfoBoulder() {
        UserRef.child(currentUserID).addListenerForSingleValueEvent(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()){
                    String latlong = latitude+longitude;
                    latlong = latlong.replaceAll("\\.", "");
                    if(location == null){
                        location = "Sitio desconocido";

                    }
                    location.replaceAll("\\b, null\\b", "");

                    HashMap boulderHash = new HashMap();
                    boulderHash.put("boulderkey", latlong);
                    boulderHash.put("userid", currentUserID);
                    boulderHash.put("username", dataSnapshot.child("username").getValue().toString());
                    boulderHash.put("profileimage", dataSnapshot.child("profileimage").getValue().toString());
                    boulderHash.put("profilestorage", storage);
                    boulderHash.put("name", name);
                    boulderHash.put("grade", grade);
                    boulderHash.put("height", height);
                    boulderHash.put("latitude", latitude);
                    boulderHash.put("longitude", longitude);
                    boulderHash.put("description", description);
                    boulderHash.put("images", downloadURL1);
                    boulderHash.put("location", location);
                    boulderHash.put("rate", "0");
                    boulderHash.put("numberOfVots", "0");

                    final String finalLatlong = latlong;
                    BoulderRef.child(latlong).updateChildren(boulderHash).addOnCompleteListener(new OnCompleteListener() {
                        @Override
                        public void onComplete(@NonNull Task task) {
                            if(task.isSuccessful()){

                                HashMap boulderImageHash = new HashMap();
                                boulderImageHash.put("images", downloadURL1);
                                boulderImageHash.put("profilestorage", storage);

                                BoulderRef.child(finalLatlong).child("BoulderImages").push().updateChildren(boulderImageHash);
                                loadingBar.dismiss();
                                SendUserToMainActivity();
                            }else{
                                Toast.makeText(BoulderActivity.this, "Error:", Toast.LENGTH_SHORT).show();
                                loadingBar.dismiss();
                            }
                        }
                    });





                }

            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

    }

    private void SendUserToMainActivity() {
        Intent mainIntent = new Intent(BoulderActivity.this, MainActivity.class);
        startActivity(mainIntent);
        finish();
    }

    private void openGallery() {
        Intent galleryIntent = new Intent();
        galleryIntent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true);
        galleryIntent.setAction(Intent.ACTION_GET_CONTENT);
        galleryIntent.setType("image/*");
        startActivityForResult(galleryIntent, Gallery_Pick);
    }

    @Override
    public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
        grade = parent.getItemAtPosition(position).toString();
    }

    @Override
    public void onNothingSelected(AdapterView<?> parent) {

    }

    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data){
        super.onActivityResult(resultCode,resultCode,data);
           /* if(requestCode==REQUEST_CAMERA && resultCode==RESULT_OK && data!=null){
                    ImageUri = data.getData();
                    CropImage.activity(ImageUri)
                        .setGuidelines(CropImageView.Guidelines.ON)
                        .setAspectRatio(1, 1)
                        .start(this);
            }else */
        if(requestCode==Gallery_Pick && resultCode==RESULT_OK && data!=null){
            ImageUri = data.getData();
            CropImage.activity(ImageUri)
                    .setGuidelines(CropImageView.Guidelines.ON)
                    .setAspectRatio(1, 1)
                    .start(this);


            //imageView.setImageURI(selectedImageUri);
        }

        if(requestCode==CropImage.CROP_IMAGE_ACTIVITY_REQUEST_CODE)
        {
            CropImage.ActivityResult result = CropImage.getActivityResult(data);

            if(resultCode == RESULT_OK)
            {
                ImageUri = result.getUri();
                try {

                    //bitmap.compress(Bitmap.CompressFormat.JPEG, 0, stream);
                    //byte[] byteArray = stream.toByteArray();
                    //Bitmap compressedBitmap = BitmapFactory.decodeByteArray(byteArray,0,byteArray.length);
                    //String path = MediaStore.Images.Media.insertImage(this.getContentResolver(), compressedBitmap, "Title", null);
                    Bitmap bitmap = MediaStore.Images.Media.getBitmap(this.getContentResolver(), ImageUri);
                    int nh = (int) ( bitmap.getHeight() * (512.0 / bitmap.getWidth()) );
                    Bitmap scaled = Bitmap.createScaledBitmap(bitmap, 512, nh, true);
                    String path = MediaStore.Images.Media.insertImage(this.getContentResolver(), scaled, "Title", null);
                    ImageUri = Uri.parse(path);
                    boulderImage.setImageBitmap(bitmap);

                } catch (IOException e) {
                    e.printStackTrace();
                }
                //boulderImage.setImageURI(ImageUri);
            }
        }

    }
}
