package com.example.kurama.aprieta;

import android.content.Intent;
import android.content.pm.PackageManager;
import android.location.Location;
import android.support.v4.app.ActivityCompat;
import android.support.v4.app.FragmentActivity;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.widget.ImageButton;

import com.google.android.gms.location.FusedLocationProviderClient;
import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.OnMapReadyCallback;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.BitmapDescriptorFactory;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;

import java.math.RoundingMode;
import java.text.DecimalFormat;

import static android.Manifest.permission.ACCESS_FINE_LOCATION;
import static com.google.android.gms.maps.GoogleMap.MAP_TYPE_HYBRID;

public class BoulderMapNotLogedActivity extends FragmentActivity implements OnMapReadyCallback {
    Toolbar mToolbar;
    private GoogleMap map;
    private ImageButton backArrow;

    Double longitude, latitude;

    private DatabaseReference BoulderRef;

    private Double Latitude, Longitude;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_map_not_loged);

        BoulderRef = FirebaseDatabase.getInstance().getReference().child("Boulders");
        Latitude = Double.parseDouble(getIntent().getExtras().get("Latitude").toString());
        Longitude = Double.parseDouble(getIntent().getExtras().get("Longitude").toString());

        SupportMapFragment mapFragment = (SupportMapFragment) getSupportFragmentManager().findFragmentById(R.id.mapNotLoged);
        mapFragment.getMapAsync(BoulderMapNotLogedActivity.this);

        backArrow = findViewById(R.id.backarrowNotLoged);
        backArrow.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent mainIntent = new Intent(BoulderMapNotLogedActivity.this, MainActivity.class);
                startActivity(mainIntent);
                finish();
            }
        });
    }

    @Override
    public void onMapReady(GoogleMap googleMap) {
        map = googleMap;
        map.setMapType(MAP_TYPE_HYBRID);


        BoulderRef.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if (dataSnapshot.exists()) {
                    for (final DataSnapshot ds : dataSnapshot.getChildren()) {
                        LatLng Usurbil = new LatLng(Double.parseDouble(ds.child("latitude").getValue().toString()), Double.parseDouble(ds.child("longitude").getValue().toString()));

                        map.addMarker(new MarkerOptions().position(Usurbil).title(ds.child("name").getValue().toString()).snippet("Grados: " + ds.child("grade").getValue().toString() + "  Valoración: " +
                                ds.child("rate").getValue().toString() + "/5")
                                .icon(BitmapDescriptorFactory.defaultMarker(BitmapDescriptorFactory.HUE_RED)));
                    }

                }
                LatLng Actual = new LatLng(Latitude, Longitude);
                map.moveCamera(CameraUpdateFactory.newLatLng(Actual));
                map.animateCamera(CameraUpdateFactory.newLatLngZoom(Actual, 13));

                map.setOnInfoWindowClickListener(new GoogleMap.OnInfoWindowClickListener() {
                    @Override
                    public void onInfoWindowClick(Marker marker) {
                        SendUserToBoulderProfileActivity(marker.getPosition().latitude, marker.getPosition().longitude);
                    }
                });

            }


            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });
    }

    private void SendUserToBoulderProfileActivity(double latitude, double longitude) {
        Intent mainIntent = new Intent(BoulderMapNotLogedActivity.this, BoulderProfileMapActivity.class);
        String lat = String.valueOf(latitude);
        String lon = String.valueOf(longitude);
        mainIntent.putExtra("BoulderKey", lat+lon);
        startActivity(mainIntent);
        finish();
    }
}
