package com.example.kurama.aprieta;

import android.media.MediaPlayer;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.widget.MediaController;
import android.widget.RatingBar;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.VideoView;

import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;

import java.util.HashMap;

import static android.view.View.GONE;

public class BoulderVideoActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private RatingBar ratingBar, ratingBar2;
    private VideoView videoView;
    private TextView description;

    private FirebaseAuth mAuth;
    private DatabaseReference BoulderRef;

    private String currentUserID, BoulderKey, VideoKey, numberOfVots, rate;


    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_boulder_video);

        BoulderKey = getIntent().getExtras().get("BoulderKey").toString();
        VideoKey = getIntent().getExtras().get("VideoKey").toString();

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        BoulderRef = FirebaseDatabase.getInstance().getReference().child("Boulders").child(BoulderKey).child("BoulderVideos").child(VideoKey);

        ratingBar = findViewById(R.id.bouldervideo_rate);
        ratingBar2 = findViewById(R.id.bouldervideo_rate2);
        videoView = findViewById(R.id.bouldervideoView);
        description = findViewById(R.id.bouldervideo_description);


        ratingBar2.setClickable(false);
        ratingBar2.setIsIndicator(true);
        ratingBar2.setVisibility(View.VISIBLE);
        BoulderRef.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()){
                    ratingBar2.setRating(Integer.parseInt(dataSnapshot.child("rate").getValue().toString()));

                    videoView.setVideoPath(dataSnapshot.child("video").getValue().toString());
                    videoView.setOnPreparedListener(new MediaPlayer.OnPreparedListener() {
                        @Override
                        public void onPrepared(MediaPlayer mp) {
                            MediaController mediaController = new MediaController(BoulderVideoActivity.this);
                            mediaController.setAnchorView(videoView);
                            videoView.setMediaController(mediaController);
                            videoView.start();
                        }
                    });



                    description.setText(dataSnapshot.child("description").getValue().toString());
                    mToolbar = (Toolbar) findViewById(R.id.bouldervideo_toolbar);
                    setSupportActionBar(mToolbar);
                    getSupportActionBar().setTitle(dataSnapshot.child("videoTitle").getValue().toString());
                    getSupportActionBar().setDisplayHomeAsUpEnabled(true);

                    if(dataSnapshot.child(currentUserID+"voted").exists()){

                        ratingBar.setVisibility(View.GONE);
                        ratingBar2.setVisibility(View.VISIBLE);

                    }else{
                        ratingBar.setVisibility(View.VISIBLE);
                        ratingBar2.setVisibility(View.VISIBLE);

                    }

                    numberOfVots = dataSnapshot.child("numberOfVots").getValue().toString();
                    rate = dataSnapshot.child("rate").getValue().toString();

                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });



        ratingBar.setOnRatingBarChangeListener(new RatingBar.OnRatingBarChangeListener() {
            @Override
            public void onRatingChanged(RatingBar ratingBar, float rating, boolean fromUser) {
                int actualRate = (int) ratingBar.getRating();
                if (actualRate != 0) {
                    int totalRates = Integer.parseInt(numberOfVots) + 1;
                    int storedRates = Integer.parseInt(rate);
                    int avgRate = (storedRates + actualRate) / totalRates;

                    BoulderRef.child("numberOfVots").setValue(String.valueOf(totalRates));
                    BoulderRef.child("rate").setValue(String.valueOf(avgRate));

                    HashMap hash = new HashMap();
                    hash.put(currentUserID+"voted", currentUserID);

                    BoulderRef.updateChildren(hash);
                    ratingBar2.setRating(avgRate);
                    ratingBar.setVisibility(GONE);
                    ratingBar2.setVisibility(View.VISIBLE);

                } else {
                    Toast.makeText(BoulderVideoActivity.this, "No se puede votar con 0", Toast.LENGTH_LONG).show();
                }
            }

        });


    }
}
