package com.example.kurama.aprieta;

import android.content.Intent;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import de.hdodenhof.circleimageview.CircleImageView;
import io.netopen.hotbitmapgg.library.view.RingProgressBar;

public class ChallengeCompletedUsersActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private RecyclerView userList;

    private FirebaseAuth mAuth;
    private DatabaseReference UserRef, ChallengeRef;
    private String currentUserID, ChallengeKey;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_challenge_completed_users);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        ChallengeKey = getIntent().getExtras().get("ChallengeKey").toString();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");
        ChallengeRef = FirebaseDatabase.getInstance().getReference().child("Challenges").child(ChallengeKey);

        mToolbar = (Toolbar) findViewById(R.id.challengedComplete_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.challenge_profile_complete);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        userList = (RecyclerView) findViewById(R.id.challengeComplete_users_list);
        userList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        userList.setLayoutManager(linearLayoutManager);

        ChallengeRef.child("ChallengeComplete").addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()){
                    diplayChallengeCompleteUsers();
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

    }

    private void diplayChallengeCompleteUsers() {
        Query searchPeople = ChallengeRef.child("ChallengeComplete").orderByKey();

        FirebaseRecyclerOptions<FindFriends> options=new FirebaseRecyclerOptions.Builder<FindFriends>().setQuery(searchPeople,FindFriends.class).build();
        FirebaseRecyclerAdapter<FindFriends, ChallengeCompletedUsersActivity.ChallengeCompleteViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindFriends, ChallengeCompletedUsersActivity.ChallengeCompleteViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final ChallengeCompletedUsersActivity.ChallengeCompleteViewHolder holder, int position, @NonNull FindFriends model) {
                final String ProfileKey = getRef(position).getKey();
                UserRef.child(ProfileKey).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()){
                            holder.username.setText(dataSnapshot.child("username").getValue().toString());
                            holder.fullname.setText(dataSnapshot.child("fullname").getValue().toString());

                            holder.personLevel.setText(dataSnapshot.child("Level").child("actualLevel").getValue().toString());
                            holder.userlevel.setMax(Integer.parseInt(dataSnapshot.child("Level").child("EXP").getValue().toString()));
                            holder.userlevel.setProgress(Integer.parseInt(dataSnapshot.child("Level").child("actualEXP").getValue().toString()));

                            Picasso.get().load(dataSnapshot.child("profileimage").getValue().toString()).into(holder.user_profile_image);
                            holder.mView.setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {

                                    if(currentUserID.equals(ProfileKey)){
                                        SendUserToProfileAcitivity();
                                    }else{
                                        Intent clickProfileIntent = new Intent(ChallengeCompletedUsersActivity.this, PersonProfileActivity.class);
                                        clickProfileIntent.putExtra("ProfileKey", ProfileKey);
                                        startActivity(clickProfileIntent);
                                    }

                                }
                            });

                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });

            }

            @NonNull
            @Override
            public ChallengeCompletedUsersActivity.ChallengeCompleteViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_user_display_layout,parent,false);
                ChallengeCompletedUsersActivity.ChallengeCompleteViewHolder viewHolder=new ChallengeCompletedUsersActivity.ChallengeCompleteViewHolder(view);
                return viewHolder;
            }
        };
        userList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();
    }

    public class ChallengeCompleteViewHolder extends RecyclerView.ViewHolder{

        TextView fullname,username, personLevel;
        RingProgressBar userlevel;
        CircleImageView user_profile_image;
        View mView;
        public ChallengeCompleteViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            username=mView.findViewById(R.id.all_users_profile_username);
            fullname=mView.findViewById(R.id.all_users_profile_name);
            user_profile_image=mView.findViewById(R.id.all_users_profile_image);
            userlevel=mView.findViewById(R.id.userlevel_load3);
            personLevel=mView.findViewById(R.id.personLevel);

        }

    }

    private void SendUserToProfileAcitivity() {
        Intent profileIntent = new Intent(ChallengeCompletedUsersActivity.this, ProfileActivity.class);
        startActivity(profileIntent);
        finish();
    }


}
