package com.example.kurama.aprieta;

import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.support.annotation.NonNull;
import android.support.v4.graphics.ColorUtils;
import android.support.v7.app.AlertDialog;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.RatingBar;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;

import okhttp3.Challenge;

import static android.view.View.GONE;

public class ChallengeProfileActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private ImageButton addChallengeToDo, deleteChallengeToDo, deleteChallenge;
    private RatingBar ratingBar, ratingBar2;
    private TextView challengeVotes, challengeProDifficulty, numberOfUsers;
    private RecyclerView challengeProfilBoulderList;

    private DatabaseReference ChallengeRef, UserRef, BoulderRef, UsersRef;
    private FirebaseAuth mAuth;

    private String currentUserID, ChallengeKey, numberOfVots, rate;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_challenge_profile);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        ChallengeKey = getIntent().getExtras().get("ChallengeKey").toString();
        ChallengeRef = FirebaseDatabase.getInstance().getReference().child("Challenges").child(ChallengeKey);
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users").child(currentUserID);
        UsersRef = FirebaseDatabase.getInstance().getReference().child("Users");
        BoulderRef = FirebaseDatabase.getInstance().getReference().child("Boulders");

        mToolbar = (Toolbar) findViewById(R.id.challenge_profile_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle("");
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        addChallengeToDo = findViewById(R.id.addToDoChallenges);
        deleteChallengeToDo = findViewById(R.id.deleteToDoChallenges);
        deleteChallenge = findViewById(R.id.deleteChallenge);
        ratingBar = findViewById(R.id.challengeRate);
        ratingBar2 = findViewById(R.id.challengeRate2);
        challengeVotes = findViewById(R.id.challengeVotes);
        challengeProDifficulty = findViewById(R.id.challengeProDifficulty);
        numberOfUsers = findViewById(R.id.numberOfUsers);

        challengeProfilBoulderList = findViewById(R.id.challengeProfilBoulderList);
        challengeProfilBoulderList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        challengeProfilBoulderList.setLayoutManager(linearLayoutManager);

        ratingBar2.setClickable(false);
        ratingBar2.setIsIndicator(true);
        ratingBar2.setVisibility(View.VISIBLE);

        ChallengeRef.addListenerForSingleValueEvent(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(currentUserID.equals(dataSnapshot.child("userID").getValue().toString())){
                    deleteChallenge.setVisibility(View.VISIBLE);
                }else{
                    deleteChallenge.setVisibility(GONE);
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

        UserRef.child("OwnChallenges").addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()){
                    if(dataSnapshot.hasChild(ChallengeKey)){
                        addChallengeToDo.setVisibility(GONE);
                        deleteChallengeToDo.setVisibility(View.VISIBLE);

                    }else{
                        addChallengeToDo.setVisibility(View.VISIBLE);
                        deleteChallengeToDo.setVisibility(GONE);


                    }
                }else{
                    addChallengeToDo.setVisibility(View.VISIBLE);
                    deleteChallengeToDo.setVisibility(GONE);

                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

        deleteChallengeToDo.setOnClickListener(new View.OnClickListener() {

            @Override
            public void onClick(View v) {
                ChallengeRef.child("Participants").child(currentUserID).removeValue();

                AlertDialog.Builder builder = new AlertDialog.Builder(ChallengeProfileActivity.this);
                builder.setTitle(R.string.challenge_profile_noPartTitle);
                builder.setPositiveButton(R.string.accept, new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                SendUserToMyChallengesActivity();
                                UserRef.child("OwnChallenges").child(ChallengeKey).removeValue();
                                Toast.makeText(ChallengeProfileActivity.this, R.string.challenge_profile_noPart, Toast.LENGTH_SHORT).show();
                            }
                });

                builder.setNegativeButton(R.string.boulder_profile_cancelAlert, new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        dialog.cancel();
                    }
                });

                AlertDialog dialog = builder.create();
                dialog.show();
                dialog.setCanceledOnTouchOutside(false);

                deleteChallengeToDo.setVisibility(GONE);
                addChallengeToDo.setVisibility(View.VISIBLE);
            }
        });

        deleteChallenge.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                AlertDialog.Builder builder = new AlertDialog.Builder(ChallengeProfileActivity.this);
                builder.setTitle(R.string.challenge_profile_deleteTitle);
                builder.setPositiveButton(R.string.accept, new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        UsersRef.addListenerForSingleValueEvent(new ValueEventListener() {
                            @Override
                            public void onDataChange(DataSnapshot dataSnapshot) {
                                if(dataSnapshot.exists()){
                                    for(DataSnapshot ds : dataSnapshot.getChildren()){
                                        if(dataSnapshot.child(ds.getKey()).child("OwnChallenges").hasChild(ChallengeKey)){
                                            UsersRef.child(ds.getKey()).child("OwnChallenges").child(ChallengeKey).removeValue();
                                        }
                                    }
                                }
                            }

                            @Override
                            public void onCancelled(DatabaseError databaseError) {

                            }
                        });

                        SendUserToMyChallengesActivity();
                        ChallengeRef.removeValue();
                        Toast.makeText(ChallengeProfileActivity.this, R.string.challenge_profile_delete, Toast.LENGTH_SHORT).show();

                    }
                });

                builder.setNegativeButton(R.string.boulder_profile_cancelAlert, new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int id) {
                        dialog.cancel();
                    }
                });

                AlertDialog dialog = builder.create();
                dialog.show();
                dialog.setCanceledOnTouchOutside(false);
            }
        });

        addChallengeToDo.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Toast.makeText(ChallengeProfileActivity.this, R.string.challenge_profile_Part, Toast.LENGTH_SHORT).show();

                final HashMap ownchallenge = new HashMap();
                final HashMap boulderHash = new HashMap();
                ChallengeRef.child("Participants").child(currentUserID).child("bouldersDone").setValue("0");

                ChallengeRef.addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()){
                            for(DataSnapshot ds : dataSnapshot.child("Boulders").getChildren()){
                                ownchallenge.put("difficulty", dataSnapshot.child("difficulty").getValue().toString());
                                ownchallenge.put("distance", dataSnapshot.child("distance").getValue().toString());
                                ownchallenge.put("numberOfVots", "0");
                                ownchallenge.put("rate", "0");
                                ownchallenge.put("userID", dataSnapshot.child("userID").getValue().toString());
                                ownchallenge.put("username", dataSnapshot.child("username").getValue().toString());
                                ownchallenge.put("profileimage", dataSnapshot.child("profileimage").getValue().toString());

                                boulderHash.put("name", ds.child("name").getValue().toString());
                                boulderHash.put("location", ds.child("location").getValue().toString());
                                boulderHash.put("grade", ds.child("grade").getValue().toString());

                                UserRef.child("OwnChallenges").child(ChallengeKey).updateChildren(ownchallenge);

                                UserRef.child("OwnChallenges").child(ChallengeKey).child("Boulders").child(ds.getKey()).updateChildren(boulderHash);
                            }

                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });
            }
        });

        ChallengeRef.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()){
                    challengeVotes.setText(dataSnapshot.child("numberOfVots").getValue().toString()+" votos");
                    challengeProDifficulty.setText(dataSnapshot.child("difficulty").getValue().toString());

                    numberOfVots = dataSnapshot.child("numberOfVots").getValue().toString();
                    rate = dataSnapshot.child("rate").getValue().toString();
                    ratingBar2.setRating(Float.parseFloat(rate));
                    if(dataSnapshot.child("Votes").child(currentUserID+"voted").exists()){
                        ratingBar.setVisibility(View.GONE);
                        ratingBar2.setVisibility(View.VISIBLE);

                    }else{
                        ratingBar.setVisibility(View.VISIBLE);
                        ratingBar2.setVisibility(View.VISIBLE);
                    }

                    if(dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").exists()) {
                        ChallengeRef.child("Participants").child(currentUserID).child("bouldersDone").setValue(String.valueOf(dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").getChildrenCount()));
                    }

                    if(dataSnapshot.hasChild("ChallengeComplete")){
                        numberOfUsers.setText(String.valueOf(dataSnapshot.child("ChallengeComplete").getChildrenCount()));
                    }else{
                        numberOfUsers.setText("0");
                    }
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

        numberOfUsers.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent usersIntent = new Intent(ChallengeProfileActivity.this, ChallengeCompletedUsersActivity.class);
                usersIntent.putExtra("ChallengeKey", ChallengeKey);
                startActivity(usersIntent);
                finish();
            }
        });

        ratingBar.setOnRatingBarChangeListener(new RatingBar.OnRatingBarChangeListener() {
            @Override
            public void onRatingChanged(RatingBar ratingBar, float rating, boolean fromUser) {
                double actualRate = (double) ratingBar.getRating();
                if (actualRate != 0) {
                    double totalRatess = Double.parseDouble(numberOfVots) + 1;
                    double storedRatess = Double.parseDouble(rate);
                    double avgRates = (storedRatess + actualRate) / totalRatess;
                    int avgRate = (int) Math.round(avgRates);
                    int totalRates = (int) totalRatess;


                    ChallengeRef.child("numberOfVots").setValue(String.valueOf(totalRates));
                    ChallengeRef.child("rate").setValue(String.valueOf(avgRate));

                    HashMap hash = new HashMap();
                    hash.put(currentUserID+"voted", currentUserID);

                    ChallengeRef.child("Votes").updateChildren(hash);
                    ratingBar2.setRating(avgRate);
                    ratingBar.setVisibility(GONE);
                    ratingBar2.setVisibility(View.VISIBLE);

                } else {
                    Toast.makeText(ChallengeProfileActivity.this, "No se puede votar con 0", Toast.LENGTH_LONG).show();
                }
            }

        });

        displayAllBoulder();
    }

    private void SendUserToMyChallengesActivity() {
        Intent mainIntent = new Intent(ChallengeProfileActivity.this, ChallengesListActivity.class);
        startActivity(mainIntent);
        finish();
    }

    private void displayAllBoulder() {
        final Query searchBoulders = ChallengeRef.child("Boulders").orderByKey();

        FirebaseRecyclerOptions<FindBoulders> options=new FirebaseRecyclerOptions.Builder<FindBoulders>().setQuery(searchBoulders,FindBoulders.class).build();
        FirebaseRecyclerAdapter<FindBoulders, ChallengeProfileActivity.FindBouldersViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindBoulders, ChallengeProfileActivity.FindBouldersViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final ChallengeProfileActivity.FindBouldersViewHolder holder, int position, @NonNull final FindBoulders model) {
                final String BoulderKey = getRef(position).getKey();
                final Drawable color = holder.layout.getBackground();
                ChallengeRef.addListenerForSingleValueEvent(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").hasChild(BoulderKey)){
                            holder.layout.setBackgroundColor(ColorUtils.XYZToColor(57,69,54));
                        }else{
                            holder.layout.setBackground(color);
                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });
                holder.name.setText(model.getName());
                holder.location.setText(model.getLocation());
                holder.grade.setText(model.getGrade());
                holder.mView.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        Intent boulderProfileIntent = new Intent(ChallengeProfileActivity.this, BoulderProfileActivity.class);
                        boulderProfileIntent.putExtra("BoulderKey", BoulderKey);
                        startActivity(boulderProfileIntent);
                        finish();

                    }
                });
                Calendar date = Calendar.getInstance();
                SimpleDateFormat currentDate = new SimpleDateFormat("yyyy-MM-dd");
                final String saveCurrentDate = currentDate.format(date.getTime());

                final HashMap dateDoneBoulder = new HashMap();
                dateDoneBoulder.put("date", saveCurrentDate);

                final HashMap challengeBouldersDone = new HashMap();

                UserRef.addListenerForSingleValueEvent(new ValueEventListener() {
                    @Override
                    public void onDataChange(final DataSnapshot dataSnapshot1) {
                        if(dataSnapshot1.child("OwnChallenges").exists()){
                            if(dataSnapshot1.child("OwnChallenges").hasChild(ChallengeKey)){
                                holder.mView.setOnLongClickListener(new View.OnLongClickListener() {
                                    @Override
                                    public boolean onLongClick(View v) {
                                        challengeBouldersDone.put(BoulderKey,BoulderKey);
                                        ChallengeRef.child("Participants").child(currentUserID).child("BouldersDone").updateChildren(challengeBouldersDone);

                                        UserRef.child("doneBoulders").child(BoulderKey).updateChildren(dateDoneBoulder);

                                        BoulderRef.child(BoulderKey).addListenerForSingleValueEvent(new ValueEventListener() {
                                            @Override
                                            public void onDataChange(DataSnapshot dataSnapshot) {
                                                int m = Integer.parseInt(dataSnapshot.child("height").getValue().toString());
                                                int actualM = Integer.parseInt(dataSnapshot1.child("metrosTotal").getValue().toString());
                                                UserRef.child("metrosTotal").setValue(String.valueOf(m+actualM));
                                            }

                                            @Override
                                            public void onCancelled(DatabaseError databaseError) {

                                            }
                                        });


                                                ChallengeRef.addListenerForSingleValueEvent(new ValueEventListener() {
                                                    @Override
                                                    public void onDataChange(DataSnapshot dataSnapshot) {
                                                        if(dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").exists()){
                                                            ChallengeRef.child("Participants").child(currentUserID).child("bouldersDone").setValue(String.valueOf(dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").getChildrenCount()));
                                                            if(dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").hasChild(BoulderKey)){
                                                                holder.layout.setBackgroundColor(ColorUtils.XYZToColor(57, 69, 54));
                                                            }
                                                            if(String.valueOf(dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").getChildrenCount()).equals(String.valueOf(dataSnapshot.child("Boulders").getChildrenCount()))){
                                                                ChallengeRef.child("ChallengeComplete").child(currentUserID).child("userID").setValue(currentUserID);
                                                                UserRef.child("doneChallenges").child(ChallengeKey).setValue(saveCurrentDate);
                                                                Toast.makeText(ChallengeProfileActivity.this, "FELICIDADES!!, RETO COMPLETADO!!", Toast.LENGTH_LONG).show();
                                                                int actualEXP = Integer.parseInt(dataSnapshot1.child("Level").child("actualEXP").getValue().toString());
                                                                int actualLevel = Integer.parseInt(dataSnapshot1.child("Level").child("actualLevel").getValue().toString());
                                                                String level = dataSnapshot1.child("level").getValue().toString();
                                                                long EXP=1000, EXPforChallenge=0;
                                                                if(dataSnapshot.child("difficulty").getValue().toString().equals("Facil")){
                                                                    EXPforChallenge = dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").getChildrenCount() * 300;
                                                                }else if(dataSnapshot.child("difficulty").getValue().toString().equals("Medio")){
                                                                    EXPforChallenge = dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").getChildrenCount() * 400;
                                                                }else if(dataSnapshot.child("difficulty").getValue().toString().equals("Dificil")){
                                                                    EXPforChallenge = dataSnapshot.child("Participants").child(currentUserID).child("BouldersDone").getChildrenCount() * 500;
                                                                }

                                                                if(actualLevel==1){
                                                                    EXP = 1000;
                                                                    actualEXP += EXPforChallenge;
                                                                    level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 1500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-1000;EXP = 1500;
                                                                        level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }

                                                                }else if(actualLevel==2){
                                                                    EXP = 1500;
                                                                    actualEXP += EXPforChallenge;
                                                                    level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 2000;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-1500;EXP = 2000;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==3){
                                                                    EXP = 2000;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 2500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-2000;EXP = 2500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==4){
                                                                    EXP = 2500;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-2500;EXP = 3000;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==5){
                                                                    EXP = 3000;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 3500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-3000;EXP = 3500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==6){
                                                                    EXP = 3500;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 4000;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-3500;EXP = 4000;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==7){
                                                                    EXP = 4000;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 4500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-4000;EXP = 4500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==8){
                                                                    EXP = 4500;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 5000;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-4500;EXP = 5000;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==9){
                                                                    EXP = 5000;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    if(actualEXP==EXP){
                                                                        actualLevel++;
                                                                        actualEXP = 0;EXP = 5500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }else if(actualEXP>EXP){
                                                                        actualLevel++;actualEXP=actualEXP-5000;EXP = 5500;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                    }
                                                                }else if(actualLevel==10){
                                                                    EXP = 5500;
                                                                    actualEXP += EXPforChallenge;level = String.valueOf(actualLevel)+String.valueOf(actualEXP);
                                                                }

                                                                UserRef.child("Level").child("EXP").setValue(String.valueOf(EXP));
                                                                UserRef.child("Level").child("actualEXP").setValue(String.valueOf(actualEXP));
                                                                UserRef.child("Level").child("actualLevel").setValue(String.valueOf(actualLevel));
                                                                UserRef.child("level").setValue(level);



                                                            }
                                                        }
                                                    }

                                                    @Override
                                                    public void onCancelled(DatabaseError databaseError) {

                                                    }
                                                });
                                           // }

                                        //});

                                       // AlertDialog dialog = builder.create();
                                      //  dialog.show();
                                        //dialog.setCanceledOnTouchOutside(false);



                                        return true;
                                    }
                                });
                            }
                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });

            }

            @NonNull
            @Override
            public ChallengeProfileActivity.FindBouldersViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_boulder_display_layout,parent,false);
                ChallengeProfileActivity.FindBouldersViewHolder viewHolder=new ChallengeProfileActivity.FindBouldersViewHolder(view);
                return viewHolder;
            }
        };
        challengeProfilBoulderList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();

    }

    public static class FindBouldersViewHolder extends RecyclerView.ViewHolder{
        RelativeLayout layout;
        TextView name, location, grade;
        View mView;
        public FindBouldersViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            layout = mView.findViewById(R.id.size);
            name=mView.findViewById(R.id.all_boulder_name);
            location=mView.findViewById(R.id.all_boulder_location);
            grade=mView.findViewById(R.id.all_grade);
        }


    }

}
