package com.example.kurama.aprieta;

import android.provider.DocumentsContract;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.ChildEventListener;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.hdodenhof.circleimageview.CircleImageView;

public class ChatActivity extends AppCompatActivity {

    private Toolbar mToolbar;

    private CircleImageView userProf;
    private TextView username;

    private RecyclerView userMessageList;
    private List<Messages> messagesList;
    private MessageAdapter messageAdapter;

    private ImageButton sendMessageButton;
    private EditText userMessageInput;

    private FirebaseAuth mAuth;
    private DatabaseReference UserRef, RootRef;
    private String messageReceiverID, messageSenderID;
    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_chat);

        messageReceiverID = getIntent().getExtras().get("ProfileKey").toString();

        mAuth = FirebaseAuth.getInstance();
        messageSenderID = mAuth.getCurrentUser().getUid();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");
        RootRef = FirebaseDatabase.getInstance().getReference();

        mToolbar = (Toolbar) findViewById(R.id.chat_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle("");
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        userMessageInput = (EditText) findViewById(R.id.add_chat_message);
        sendMessageButton = (ImageButton) findViewById(R.id.send_chat);
        userProf = (CircleImageView) findViewById(R.id.chatprofileimage);
        username = (TextView) findViewById(R.id.userchatname);

        //messageAdapter = new MessageAdapter(messagesList);
        userMessageList = (RecyclerView) findViewById(R.id.chat_message);
        userMessageList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(getApplicationContext());
        linearLayoutManager.setStackFromEnd(true);
        userMessageList.setLayoutManager(linearLayoutManager);
      //  userMessageList.setAdapter(messageAdapter);

        UserRef.child(messageReceiverID).addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()){
                    username.setText(dataSnapshot.child("username").getValue().toString());
                    Picasso.get().load(dataSnapshot.child("profileimage").getValue().toString()).placeholder(R.drawable.profile).into(userProf);

                    readMessages(messageSenderID, messageReceiverID, dataSnapshot.child("profileimage").getValue().toString());

                }else{
                    username.setText("Admin");
                    readMessages(messageSenderID, messageReceiverID, "");

                }

            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

        sendMessageButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String msg = userMessageInput.getText().toString();
                if(!msg.equals("")){
                    SendMessage(messageSenderID, messageReceiverID, msg);
                }

                userMessageInput.setText("");
            }
        });


    }



    private void SendMessage(String sender, String receiver, String message) {
        HashMap<String, Object> hashMap = new HashMap<>();
        hashMap.put("sender",sender);
        hashMap.put("receiver",receiver);
        hashMap.put("message",message);

        RootRef.child("Chats").push().setValue(hashMap);
    }

    private void readMessages(final String senderID, final String receiverID, final String imageURL){
        messagesList = new ArrayList<>();
        RootRef.child("Chats").addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                messagesList.clear();
                for(DataSnapshot ds : dataSnapshot.getChildren()){
                    Messages msg = ds.getValue(Messages.class);
                    if(msg.getReceiver().equals(senderID) && msg.getSender().equals(receiverID) || msg.getReceiver().equals(receiverID) && msg.getSender().equals(senderID)){
                        messagesList.add(msg);
                    }

                    messageAdapter = new MessageAdapter(ChatActivity.this, messagesList, imageURL);
                    userMessageList.setAdapter(messageAdapter);
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

    }
}
