package com.example.kurama.aprieta;

import android.content.Intent;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageButton;
import android.widget.TextView;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import de.hdodenhof.circleimageview.CircleImageView;
import io.netopen.hotbitmapgg.library.view.RingProgressBar;

public class ChatAdminActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private RecyclerView friendList;
    private ImageButton userChat;

    private FirebaseAuth mAuth;
    private DatabaseReference FriendsRef, UserRef;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
       SendUserToMainActivity();
    }
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_chat_menu);


        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");
        FriendsRef = FirebaseDatabase.getInstance().getReference().child("Admin").child("MessagesWith");

        mToolbar = (Toolbar) findViewById(R.id.chat_friend_list_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.message_menu_title);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);


        userChat = (ImageButton) findViewById(R.id.chooseUserToChat);
        friendList = (RecyclerView) findViewById(R.id.users_chat_friend_list);
        friendList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        friendList.setLayoutManager(linearLayoutManager);

        userChat.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {

                SendUserToUserListActivity();
            }
        });

        diplayAllFriends();
    }

    private void SendUserToUserListActivity() {
        Intent friendListIntent = new Intent(ChatAdminActivity.this, AllUserActivity.class);
        startActivity(friendListIntent);
        finish();
    }

    private void SendUserToMainActivity() {
        Intent mainIntent = new Intent(ChatAdminActivity.this, Main2Activity.class);
        mainIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(mainIntent);
        finish();
    }

    private void diplayAllFriends() {
        Query searchPeople = FriendsRef.orderByKey();

        FirebaseRecyclerOptions<FindFriends> options=new FirebaseRecyclerOptions.Builder<FindFriends>().setQuery(searchPeople,FindFriends.class).build();
        FirebaseRecyclerAdapter<FindFriends, ChatAdminActivity.FrienListViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindFriends, ChatAdminActivity.FrienListViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final ChatAdminActivity.FrienListViewHolder holder, int position, @NonNull FindFriends model) {
                final String ProfileKey = getRef(position).getKey();
                UserRef.child(ProfileKey).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()){
                            holder.username.setText(dataSnapshot.child("username").getValue().toString());
                            holder.fullname.setText(dataSnapshot.child("fullname").getValue().toString());
                            holder.personLevel.setText(dataSnapshot.child("Level").child("actualLevel").getValue().toString());
                            holder.userlevel.setMax(Integer.parseInt(dataSnapshot.child("Level").child("EXP").getValue().toString()));
                            holder.userlevel.setProgress(Integer.parseInt(dataSnapshot.child("Level").child("actualEXP").getValue().toString()));
                            Picasso.get().load(dataSnapshot.child("profileimage").getValue().toString()).into(holder.user_profile_image);
                            holder.mView.setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {
                                    Intent clickProfileIntent = new Intent(ChatAdminActivity.this, ChatActivity.class);
                                    clickProfileIntent.putExtra("ProfileKey", ProfileKey);
                                    startActivity(clickProfileIntent);

                                }
                            });

                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });

            }

            @NonNull
            @Override
            public ChatAdminActivity.FrienListViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_user_display_layout,parent,false);
                ChatAdminActivity.FrienListViewHolder viewHolder=new ChatAdminActivity.FrienListViewHolder(view);
                return viewHolder;
            }
        };
        friendList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();
    }



    public class FrienListViewHolder extends RecyclerView.ViewHolder{

        TextView fullname,username, personLevel;
        RingProgressBar userlevel;
        CircleImageView user_profile_image;
        View mView;
        public FrienListViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            username=mView.findViewById(R.id.all_users_profile_username);
            fullname=mView.findViewById(R.id.all_users_profile_name);
            user_profile_image=mView.findViewById(R.id.all_users_profile_image);
            userlevel=mView.findViewById(R.id.userlevel_load3);
            personLevel=mView.findViewById(R.id.personLevel);
        }

    }


}
