package com.example.kurama.aprieta;

import android.os.Build;
import android.support.annotation.NonNull;
import android.support.annotation.RequiresApi;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.Toolbar;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;

import de.hdodenhof.circleimageview.CircleImageView;

public class CommentsActivity extends AppCompatActivity {

    private android.support.v7.widget.Toolbar mToolbar;

    private FirebaseAuth mAuth;
    private DatabaseReference UserRef,PostRef, Post_Ref;

    private ImageButton postCommentButton;
    private EditText CommentInputText;
    private RecyclerView commentList;

    private CircleImageView commentProfileImage;
    private TextView commentDescription, usernameComment;

    private String Post_Key, currentUserID;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_comments);

        Post_Key = getIntent().getExtras().get("PostKey").toString();

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");
        PostRef = FirebaseDatabase.getInstance().getReference().child("Post");
        Post_Ref = FirebaseDatabase.getInstance().getReference().child("Post").child(Post_Key).child("Comments");

        mToolbar =(android.support.v7.widget.Toolbar) findViewById(R.id.comment_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.comments_title);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        postCommentButton = (ImageButton) findViewById(R.id.send_comment);
        CommentInputText = (EditText) findViewById(R.id.new_comment);
        commentProfileImage = (CircleImageView) findViewById(R.id.users_profile_comment_image);
        commentDescription = (TextView) findViewById(R.id.users_post_description_comment);
        usernameComment = (TextView) findViewById(R.id.username_comment);

        commentList = (RecyclerView) findViewById(R.id.comments_list);
        commentList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        commentList.setLayoutManager(linearLayoutManager);

        postCommentButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                UserRef.child(currentUserID).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()){
                            String username = dataSnapshot.child("username").getValue().toString();
                            String profilepic = dataSnapshot.child("profileimage").getValue().toString();
                            validateComment(username, profilepic);
                            CommentInputText.setText("");
                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });
            }
        });

       PostRef.child(Post_Key).addValueEventListener(new ValueEventListener() {
           @Override
           public void onDataChange(DataSnapshot dataSnapshot) {
               if(dataSnapshot.exists()) {
                   if (dataSnapshot.hasChild("fullname")) {
                       String username = dataSnapshot.child("fullname").getValue().toString();
                       usernameComment.setText(username);
                   }
                   if (dataSnapshot.hasChild("profileimage")) {
                       String image = dataSnapshot.child("profileimage").getValue().toString();
                       Picasso.get().load(image).placeholder(R.drawable.profile).into(commentProfileImage);
                   }
                   if(dataSnapshot.hasChild("status")){
                       String status = dataSnapshot.child("status").getValue().toString();
                       commentDescription.setText(status);
                   }
               }
           }

           @Override
           public void onCancelled(DatabaseError databaseError) {

           }
       });

       DisplayAllComments();

    }

    private void DisplayAllComments() {
        FirebaseRecyclerOptions<Comments> options=new FirebaseRecyclerOptions.Builder<Comments>().setQuery(Post_Ref,Comments.class).build();
        FirebaseRecyclerAdapter<Comments, CommentsActivity.CommentsViewHolder> firebaseRecyclerAdapter=new FirebaseRecyclerAdapter<Comments, CommentsActivity.CommentsViewHolder>(options){

            @Override
            protected void onBindViewHolder(@NonNull final CommentsViewHolder holder, int position, @NonNull final Comments model) {
                final String CommentKey = getRef(position).getKey();
                UserRef.child(model.getUid()).addListenerForSingleValueEvent(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()){
                            holder.username.setText(dataSnapshot.child("username").getValue().toString());
                            holder.comment.setText(model.getComment());
                            holder.date.setText(model.getDate());
                            holder.time.setText(model.getTime());
                            Picasso.get().load(dataSnapshot.child("profileimage").getValue().toString()).into(holder.profileImage);
                            if(!currentUserID.equals(model.getUid()) && !currentUserID.equals("LiApsI6W5uVfOFBZdyqgRBpL9li1")){
                                holder.deleteComment.setVisibility(View.GONE);
                            }else{
                                holder.deleteComment.setVisibility(View.VISIBLE);

                                holder.deleteComment.setOnClickListener(new View.OnClickListener() {
                                    @Override
                                    public void onClick(View v) {
                                        Post_Ref.child(CommentKey).removeValue();
                                    }
                                });
                            }
                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });

            }

            @NonNull
            @Override
            public CommentsViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_comments_layout,parent,false);
                CommentsActivity.CommentsViewHolder viewHolder=new CommentsActivity.CommentsViewHolder(view);
                return viewHolder;
            }

        };
        commentList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();
    }

    public static class CommentsViewHolder extends RecyclerView.ViewHolder{

        TextView username, comment, date, time;
        CircleImageView profileImage;
        ImageButton deleteComment;

        View mView;
        public CommentsViewHolder(View itemView) {
            super(itemView);

            mView = itemView;

            username = mView.findViewById(R.id.all_user_comment_username);
            comment = mView.findViewById(R.id.all_user_comments);
            date = mView.findViewById(R.id.dateComments);
            time = mView.findViewById(R.id.timeComments);
            profileImage = mView.findViewById(R.id.all_users_comments_profile_image);
            deleteComment = mView.findViewById(R.id.delete_Comment);
        }
    }

    private void validateComment(String username, String profilepic) {
        String commentText = CommentInputText.getText().toString();
        if(TextUtils.isEmpty(commentText)){
            Toast.makeText(this, R.string.comment_addver, Toast.LENGTH_SHORT).show();
        }else{
            Calendar date = Calendar.getInstance();
            SimpleDateFormat currentDate = new SimpleDateFormat("dd-MM-yyyy");
            final String saveCurrentDate = currentDate.format(date.getTime());

            Calendar time = Calendar.getInstance();
            SimpleDateFormat currentTime = new SimpleDateFormat("HH:mm:ss");
            final String saveCurrentTime = currentTime.format(time.getTime());

            final String  commentRandomName = currentUserID + saveCurrentDate + saveCurrentTime;

            HashMap commentsMap = new HashMap();
                commentsMap.put("uid", currentUserID);
                commentsMap.put("comment", commentText);
                commentsMap.put("date", saveCurrentDate);
                commentsMap.put("time", saveCurrentTime);
                commentsMap.put("username", username);
                commentsMap.put("profileimage", profilepic);

                Post_Ref.child(commentRandomName).updateChildren(commentsMap).addOnCompleteListener(new OnCompleteListener() {
                    @Override
                    public void onComplete(@NonNull Task task) {
                        if(task.isSuccessful()){
                        }else{
                            Toast.makeText(CommentsActivity.this, "Error", Toast.LENGTH_SHORT).show();
                        }
                    }
                });



        }
    }
}
