package com.example.kurama.aprieta;

import android.annotation.TargetApi;
import android.content.Intent;
import android.os.Build;
import android.support.annotation.NonNull;
import android.support.annotation.RequiresApi;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.TextView;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import de.hdodenhof.circleimageview.CircleImageView;
import io.netopen.hotbitmapgg.library.view.RingProgressBar;

public class FindUsersActivity extends AppCompatActivity {
    private Toolbar mToolbar;
    private ImageButton searchButton;
    private EditText searchText;

    private RecyclerView friendSearchList;

    private DatabaseReference allUserDatabaseRef;


    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        SendUserTo2MainActivity();
    }

    @TargetApi(Build.VERSION_CODES.LOLLIPOP)
    @RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_find_friends);

        allUserDatabaseRef = FirebaseDatabase.getInstance().getReference().child("Users");

        mToolbar = (Toolbar) findViewById(R.id.find_friends_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);
        getSupportActionBar().setTitle("");

        friendSearchList = (RecyclerView) findViewById(R.id.users_list);
        friendSearchList.setHasFixedSize(true);
        friendSearchList.setLayoutManager(new LinearLayoutManager(this));

        searchButton = (ImageButton) findViewById(R.id.search_button);
        searchText = (EditText) findViewById(R.id.search_friends);

        searchPeopleAndFriends("");

        searchButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String searchBox = searchText.getText().toString();
                searchPeopleAndFriends(searchBox);
            }
        });
    }

    private void searchPeopleAndFriends(String searchUser) {

        Query searchPeople = allUserDatabaseRef.orderByChild("username").startAt(searchUser).endAt(searchUser + "\uf8ff");

        FirebaseRecyclerOptions<FindFriends> options=new FirebaseRecyclerOptions.Builder<FindFriends>().setQuery(searchPeople,FindFriends.class).build();
        FirebaseRecyclerAdapter<FindFriends, FindUsersActivity.FindFriendsViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindFriends, FindUsersActivity.FindFriendsViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final FindUsersActivity.FindFriendsViewHolder holder, int position, @NonNull FindFriends model) {
                final String ProfileKey = getRef(position).getKey();
                holder.username.setText(model.getUsername());
                holder.fullname.setText(model.getFullname());
                allUserDatabaseRef.child(ProfileKey).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()) {
                            holder.personLevel.setText(dataSnapshot.child("Level").child("actualLevel").getValue().toString());
                            holder.userlevel.setMax(Integer.parseInt(dataSnapshot.child("Level").child("EXP").getValue().toString()));
                            holder.userlevel.setProgress(Integer.parseInt(dataSnapshot.child("Level").child("actualEXP").getValue().toString()));
                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });
                Picasso.get().load(model.getProfileimage()).into(holder.user_profile_image);
                holder.mView.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {

                            Intent clickProfileIntent = new Intent(FindUsersActivity.this, ProfileForAdminActivity.class);
                            clickProfileIntent.putExtra("ProfileKey", ProfileKey);
                            startActivity(clickProfileIntent);
                            finish();

                    }
                });


            }

            @NonNull
            @Override
            public FindUsersActivity.FindFriendsViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_user_display_layout,parent,false);
                FindUsersActivity.FindFriendsViewHolder viewHolder=new FindUsersActivity.FindFriendsViewHolder(view);
                return viewHolder;
            }
        };
        friendSearchList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();
    }

    private void SendUserTo2MainActivity() {
        Intent mainIntent = new Intent(FindUsersActivity.this, Main2Activity.class);
        mainIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(mainIntent);
        finish();
    }


    public static class FindFriendsViewHolder extends RecyclerView.ViewHolder{

        TextView fullname,username, personLevel;
        RingProgressBar userlevel;
        CircleImageView user_profile_image;
        View mView;
        public FindFriendsViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            username=mView.findViewById(R.id.all_users_profile_username);
            fullname=mView.findViewById(R.id.all_users_profile_name);
            user_profile_image=mView.findViewById(R.id.all_users_profile_image);
            userlevel=mView.findViewById(R.id.userlevel_load3);
            personLevel=mView.findViewById(R.id.personLevel);
        }
    }

}
