package com.example.kurama.aprieta;

import android.content.Intent;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import de.hdodenhof.circleimageview.CircleImageView;
import io.netopen.hotbitmapgg.library.view.RingProgressBar;

public class FriendToChatActivity extends AppCompatActivity {

    private Toolbar mToolbar;

    private RecyclerView friendList;

    private FirebaseAuth mAuth;
    private DatabaseReference FriendsRef, UserRef;
    private String currentUserID, otherUserID;
    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_friend_to_chat);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");
        FriendsRef = FirebaseDatabase.getInstance().getReference().child("Users").child(currentUserID).child("Friends");

        mToolbar = (Toolbar) findViewById(R.id.friend_list_toolbar_chat);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.friend_list_title);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        friendList = (RecyclerView) findViewById(R.id.users_friend_list_chat);
        friendList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        friendList.setLayoutManager(linearLayoutManager);

        diplayAllFriends();
    }

    private void diplayAllFriends() {
        Query searchPeople = FriendsRef.orderByChild("fullname");

        FirebaseRecyclerOptions<FindFriends> options=new FirebaseRecyclerOptions.Builder<FindFriends>().setQuery(searchPeople,FindFriends.class).build();
        FirebaseRecyclerAdapter<FindFriends, FriendToChatActivity.FrienListViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindFriends, FriendToChatActivity.FrienListViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final FriendToChatActivity.FrienListViewHolder holder, int position, @NonNull FindFriends model) {
                final String ProfileKey = getRef(position).getKey();
                UserRef.child(ProfileKey).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()){
                            holder.username.setText(dataSnapshot.child("username").getValue().toString());
                            holder.fullname.setText(dataSnapshot.child("fullname").getValue().toString());
                            holder.personLevel.setText(dataSnapshot.child("Level").child("actualLevel").getValue().toString());
                            holder.userlevel.setMax(Integer.parseInt(dataSnapshot.child("Level").child("EXP").getValue().toString()));
                            holder.userlevel.setProgress(Integer.parseInt(dataSnapshot.child("Level").child("actualEXP").getValue().toString()));
                            Picasso.get().load(dataSnapshot.child("profileimage").getValue().toString()).into(holder.user_profile_image);
                            holder.mView.setOnClickListener(new View.OnClickListener() {
                                @Override
                                public void onClick(View v) {

                                    FriendsRef.child(ProfileKey).child("chat").setValue("true");
                                    UserRef.child(ProfileKey).child("Friends").child(currentUserID).child("chat").setValue("true");
                                    Intent clickProfileIntent = new Intent(FriendToChatActivity.this, ChatActivity.class);
                                    clickProfileIntent.putExtra("ProfileKey", ProfileKey);
                                    startActivity(clickProfileIntent);
                                    finish();

                                }
                            });

                        }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });

            }

            @NonNull
            @Override
            public FriendToChatActivity.FrienListViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_user_display_layout,parent,false);
                FriendToChatActivity.FrienListViewHolder viewHolder=new FriendToChatActivity.FrienListViewHolder(view);
                return viewHolder;
            }
        };
        friendList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();
    }



    public class FrienListViewHolder extends RecyclerView.ViewHolder{

        TextView fullname,username, personLevel;
        RingProgressBar userlevel;
        CircleImageView user_profile_image;
        View mView;
        public FrienListViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            username=mView.findViewById(R.id.all_users_profile_username);
            fullname=mView.findViewById(R.id.all_users_profile_name);
            user_profile_image=mView.findViewById(R.id.all_users_profile_image);
            userlevel=mView.findViewById(R.id.userlevel_load3);
            personLevel=mView.findViewById(R.id.personLevel);
        }

    }

}
