package com.example.kurama.aprieta;

import android.content.Intent;
import android.graphics.Color;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import de.hdodenhof.circleimageview.CircleImageView;
import io.netopen.hotbitmapgg.library.view.RingProgressBar;

public class GlobalRankingActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private RecyclerView globalRankingList;

    private FirebaseAuth mAuth;
    private DatabaseReference UserRef;
    private String currentUserID;
    private int numofUsers=0;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_global_ranking);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");

        mToolbar = (Toolbar) findViewById(R.id.globalrank_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);
        getSupportActionBar().setTitle(R.string.nav_ranking);

        globalRankingList = (RecyclerView) findViewById(R.id.ranking_list);
        globalRankingList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        globalRankingList.setLayoutManager(linearLayoutManager);

        UserRef.addListenerForSingleValueEvent(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()){
                    numofUsers = (int)dataSnapshot.getChildrenCount();
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });


        DisplayUsers();
    }

    private void DisplayUsers() {
        Query rank = UserRef.orderByChild("level");

        FirebaseRecyclerOptions<FindFriends> options=new FirebaseRecyclerOptions.Builder<FindFriends>().setQuery(rank,FindFriends.class).build();
        FirebaseRecyclerAdapter<FindFriends, GlobalRankingActivity.RankingViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindFriends, GlobalRankingActivity.RankingViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final GlobalRankingActivity.RankingViewHolder holder, final int position, @NonNull FindFriends model) {
                final String ProfileKey = getRef(position).getKey();

                holder.username.setText(model.getUsername());
                holder.fullname.setText(model.getFullname());
                UserRef.child(ProfileKey).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        holder.personLevel.setText(dataSnapshot.child("Level").child("actualLevel").getValue().toString());
                        holder.userlevel.setMax(Integer.parseInt(dataSnapshot.child("Level").child("EXP").getValue().toString()));
                        holder.userlevel.setProgress(Integer.parseInt(dataSnapshot.child("Level").child("actualEXP").getValue().toString()));

                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });

                if(position == numofUsers-1){
                    holder.first.setVisibility(View.VISIBLE);
                    holder.second.setVisibility(View.INVISIBLE);
                    holder.third.setVisibility(View.INVISIBLE);
                    holder.rankingFirst.setBackgroundColor(Color.rgb(255,255,153));

                }else if(position == numofUsers-2){
                    holder.first.setVisibility(View.INVISIBLE);
                    holder.second.setVisibility(View.VISIBLE);
                    holder.third.setVisibility(View.INVISIBLE);
                }else if(position == numofUsers-3){
                    holder.first.setVisibility(View.INVISIBLE);
                    holder.second.setVisibility(View.INVISIBLE);
                    holder.third.setVisibility(View.VISIBLE);
                }

                Picasso.get().load(model.getProfileimage()).into(holder.user_profile_image);
                holder.mView.setOnClickListener(new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {

                        if(currentUserID.equals(ProfileKey)){
                            SendUserToProfileAcitivity();
                        }else{
                            Intent clickProfileIntent = new Intent(GlobalRankingActivity.this, PersonProfileActivity.class);
                            clickProfileIntent.putExtra("ProfileKey", ProfileKey);
                            startActivity(clickProfileIntent);
                        }


                    }
                });


            }

            @NonNull
            @Override
            public GlobalRankingActivity.RankingViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_user_display_layout,parent,false);
                GlobalRankingActivity.RankingViewHolder viewHolder=new GlobalRankingActivity.RankingViewHolder(view);
                return viewHolder;
            }
        };
        globalRankingList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();
    }

    public static class RankingViewHolder extends RecyclerView.ViewHolder{
        RelativeLayout rankingFirst;
        TextView fullname,username, personLevel;
        RingProgressBar userlevel;
        CircleImageView user_profile_image;
        ImageView first, second, third;
        View mView;
        public RankingViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            username=mView.findViewById(R.id.all_users_profile_username);
            fullname=mView.findViewById(R.id.all_users_profile_name);
            user_profile_image=mView.findViewById(R.id.all_users_profile_image);
            userlevel=mView.findViewById(R.id.userlevel_load3);
            personLevel=mView.findViewById(R.id.personLevel);
            first = mView.findViewById(R.id.idFirst);
            second = mView.findViewById(R.id.idSecond);
            third = mView.findViewById(R.id.idThird);
            rankingFirst = mView.findViewById(R.id.user_list_back);

        }
    }

    private void SendUserToProfileAcitivity() {
        Intent profileIntent = new Intent(GlobalRankingActivity.this, ProfileActivity.class);
        startActivity(profileIntent);
        finish();
    }
}
