package com.example.kurama.aprieta;

import android.content.Intent;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.StorageReference;

public class LikeBouldersActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private RecyclerView bouldersList;

    private DatabaseReference BoulderRef, UserRef;
    private FirebaseAuth mAuth;
    private String currentUserID;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_like_boulders);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users").child(currentUserID);
        BoulderRef = FirebaseDatabase.getInstance().getReference().child("Boulders");

        mToolbar = (Toolbar) findViewById(R.id.likeBoulderList_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.nav_fav);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        bouldersList = (RecyclerView) findViewById(R.id.likeBoulders_list);
        bouldersList.setHasFixedSize(true);
        bouldersList.setLayoutManager(new LinearLayoutManager(this));

        UserRef.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.hasChild("likeBoulder")){
                    displayDoneBoulders();
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

    }

    private void displayDoneBoulders() {
        Query searchBoulders = UserRef.child("likeBoulder").orderByKey();

        FirebaseRecyclerOptions<FindBoulders> options = new FirebaseRecyclerOptions.Builder<FindBoulders>().setQuery(searchBoulders, FindBoulders.class).build();
        final FirebaseRecyclerAdapter<FindBoulders, ToDoActivity.FindBouldersViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindBoulders, ToDoActivity.FindBouldersViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final ToDoActivity.FindBouldersViewHolder holder, int position, @NonNull final FindBoulders model) {
                final String BoulderKey = getRef(position).getKey();
                BoulderRef.child(BoulderKey).addValueEventListener(new ValueEventListener() {
                    @Override
                    public void onDataChange(DataSnapshot dataSnapshot) {
                        if(dataSnapshot.exists()) {
                                holder.name.setText(dataSnapshot.child("name").getValue().toString());
                                holder.location.setText(dataSnapshot.child("location").getValue().toString());
                                holder.grade.setText(dataSnapshot.child("grade").getValue().toString());
                                holder.mView.setOnClickListener(new View.OnClickListener() {
                                    @Override
                                    public void onClick(View v) {
                                        Intent boulderProfileIntent = new Intent(LikeBouldersActivity.this, BoulderProfileActivity.class);
                                        boulderProfileIntent.putExtra("BoulderKey", BoulderKey);
                                        startActivity(boulderProfileIntent);
                                        finish();

                                    }
                                });
                            }
                    }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });



            }

            @NonNull
            @Override
            public ToDoActivity.FindBouldersViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.all_boulder_display_layout, parent, false);
                ToDoActivity.FindBouldersViewHolder viewHolder = new ToDoActivity.FindBouldersViewHolder(view);
                return viewHolder;
            }
        };
        bouldersList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();
    }
}
