package com.example.kurama.aprieta;

import android.app.PendingIntent;
import android.content.Intent;
import android.net.Uri;
import android.os.Handler;
import android.support.annotation.NonNull;
import android.support.design.widget.NavigationView;
import android.support.v4.app.ActivityCompat;
import android.support.v4.app.NotificationCompat;
import android.support.v4.widget.DrawerLayout;
import android.support.v4.widget.SwipeRefreshLayout;
import android.support.v7.app.ActionBarDrawerToggle;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.auth.FirebaseUser;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;
import com.squareup.picasso.Picasso;

import de.hdodenhof.circleimageview.CircleImageView;

import static android.Manifest.permission.ACCESS_FINE_LOCATION;
import static android.Manifest.permission.WRITE_EXTERNAL_STORAGE;

public class MainActivity extends AppCompatActivity {

    private NavigationView navigationView;
    private DrawerLayout drawerLayout;
    private ActionBarDrawerToggle actionBarDrawerToggle;
    private RecyclerView postList;
    private android.support.v7.widget.Toolbar mToolbar;
    private SwipeRefreshLayout sw;

    private CircleImageView NavProfileImage;
    private TextView NavProfileUsername;

    private FirebaseAuth mAuth;
    private DatabaseReference UserRef,PostRef, LikesRef, FriendRequestRef;

    private Boolean likeChecker = false;
    private String currentUserID="",friendsID, type;

    private NotificationHelper nHelper;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        System.out.println("ID"+currentUserID);
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users");
        PostRef = FirebaseDatabase.getInstance().getReference().child("Post");
        LikesRef = FirebaseDatabase.getInstance().getReference().child("Likes");
        FriendRequestRef = FirebaseDatabase.getInstance().getReference().child("FriendRequest");

        requestPermission();
        mToolbar = (android.support.v7.widget.Toolbar) findViewById(R.id.maing_page_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle("Aprieta");
        sw = (SwipeRefreshLayout) findViewById(R.id.swipeMain);

        drawerLayout = (DrawerLayout) findViewById(R.id.drawable_layout);
        actionBarDrawerToggle = new ActionBarDrawerToggle(MainActivity.this, drawerLayout, R.string.drawer_open, R.string.drawer_close);
        drawerLayout.addDrawerListener(actionBarDrawerToggle);
        actionBarDrawerToggle.syncState();
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        navigationView = (NavigationView) findViewById(R.id.navigation_view);
        View navView = navigationView.inflateHeaderView(R.layout.navigation_header);

        postList = (RecyclerView) findViewById(R.id.all_users_post_list);
        postList.setHasFixedSize(true);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this);
        linearLayoutManager.setReverseLayout(true);
        linearLayoutManager.setStackFromEnd(true);
        postList.setLayoutManager(linearLayoutManager);

        nHelper = new NotificationHelper(this);

        NavProfileImage = (CircleImageView) navView.findViewById(R.id.nav_image);
        NavProfileUsername = (TextView) navView.findViewById(R.id.usernma_nav);

        FriendRequestRef.child(currentUserID).addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(dataSnapshot.exists()) {
                    if(dataSnapshot.getValue().toString().contains("received")) {
                        createNotification();
                    }
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

        UserRef.child(currentUserID).addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot)
            {
                if(dataSnapshot.exists())
                {

                    if(dataSnapshot.hasChild("Friends")){
                        for(DataSnapshot ds : dataSnapshot.child("Friends").getChildren()){
                            friendsID = ds.getKey();
                        }
                    }
                    DisplayAllUserPosts();
                    if(dataSnapshot.hasChild("username"))
                    {
                        String username = dataSnapshot.child("username").getValue().toString();
                        NavProfileUsername.setText(username);
                    }
                    if(dataSnapshot.hasChild("profileimage"))
                    {
                        String image = dataSnapshot.child("profileimage").getValue().toString();
                        Picasso.get().load(image).placeholder(R.drawable.profile).into(NavProfileImage);
                    }
                    else
                    {
                        Toast.makeText(MainActivity.this, "Profile name do not exists...", Toast.LENGTH_SHORT).show();
                    }



                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });


        sw.setOnRefreshListener(new SwipeRefreshLayout.OnRefreshListener() {
            @Override
            public void onRefresh() {
                DisplayAllUserPosts();
                new Handler().postDelayed(new Runnable() {
                    @Override
                    public void run() {
                        sw.setRefreshing(false);
                    }
                },2000);
            }
        });

        navigationView.setNavigationItemSelectedListener(new NavigationView.OnNavigationItemSelectedListener() {
            @Override
            public boolean onNavigationItemSelected(@NonNull MenuItem item) {
                UserMenuSelector(item);

                return false;
            }
        });

        DisplayAllUserPosts();

    }
    private void requestPermission(){
        ActivityCompat.requestPermissions(this, new String[]{ACCESS_FINE_LOCATION},1);
    }


    private void createNotification() {
        NotificationCompat.Builder nb = nHelper.getChannel1Notification();
        nHelper.getManager().notify(1, nb.build());
    }

    private void DisplayAllUserPosts() {

        Query SortPostInDescending = PostRef.orderByKey();

        FirebaseRecyclerOptions<Posts> options=new FirebaseRecyclerOptions.Builder<Posts>().setQuery(SortPostInDescending,Posts.class).build();
        FirebaseRecyclerAdapter<Posts, PostsViewHolder> firebaseRecyclerAdapter=new FirebaseRecyclerAdapter<Posts, PostsViewHolder>(options) {
            @Override
            protected void onBindViewHolder(@NonNull final PostsViewHolder holder, int position, @NonNull final Posts model) {
                final String PostKey = getRef(position).getKey();
                final String uid = model.getUid();

                            UserRef.child(currentUserID).child("Friends").addListenerForSingleValueEvent(new ValueEventListener() {
                                @Override
                                public void onDataChange(DataSnapshot dataSnapshot) {
                                    if (dataSnapshot.exists()) {

                                        if (dataSnapshot.hasChild(uid) || currentUserID.equals(uid)) {
                                            holder.username.setText(model.getFullname());
                                            holder.time.setText(" " + model.getTime());
                                            holder.date.setText(" " + model.getDate());
                                            holder.description.setText(model.getStatus());
                                            UserRef.child(model.getUid()).addValueEventListener(new ValueEventListener() {
                                                @Override
                                                public void onDataChange(DataSnapshot dataSnapshot) {
                                                    holder.username.setText(dataSnapshot.child("fullname").getValue().toString());
                                                    Picasso.get().load(dataSnapshot.child("profileimage").getValue().toString()).into(holder.user_post_image);

                                                }

                                                @Override
                                                public void onCancelled(DatabaseError databaseError) {

                                                }
                                            });

                                            if(model.getType().equals("video")){
                                                holder.postImage.setVisibility(View.GONE);
                                                holder.clickForVideo.setVisibility(View.VISIBLE);
                                            }else if(model.getType().equals("image")) {
                                                holder.clickForVideo.setVisibility(View.GONE);
                                                Picasso.get().load(model.getPostimage()).into(holder.postImage);
                                            }else if(model.getType().equals("text")){
                                                holder.postImage.setVisibility(View.GONE);
                                                holder.clickForVideo.setVisibility(View.GONE);
                                                holder.clickForText.setVisibility(View.VISIBLE);
                                                holder.description.setVisibility(View.GONE);
                                                holder.status.setText(model.getStatus());
                                            }
                                            holder.setLikeButtonStatus(PostKey);

                                            holder.user_post_image.setOnClickListener(new View.OnClickListener() {
                                                @Override
                                                public void onClick(View v) {

                                                    if (currentUserID.equals(uid)) {
                                                        Intent ownProfileIntent = new Intent(MainActivity.this, ProfileActivity.class);
                                                        startActivity(ownProfileIntent);
                                                    } else {
                                                        Intent clickProfileIntent = new Intent(MainActivity.this, PersonProfileActivity.class);
                                                        clickProfileIntent.putExtra("ProfileKey", uid);
                                                        startActivity(clickProfileIntent);
                                                    }

                                                }
                                            });
                                            holder.clickForText.setOnClickListener(new View.OnClickListener() {
                                                @Override
                                                public void onClick(View v) {
                                                    Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                    clickPostIntent.putExtra("PostKey", PostKey);
                                                    clickPostIntent.putExtra("type", model.getType());
                                                    startActivity(clickPostIntent);
                                                }
                                            });

                                            holder.post_video.setOnClickListener(new View.OnClickListener() {
                                                @Override
                                                public void onClick(View v) {
                                                    Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                    clickPostIntent.putExtra("PostKey", PostKey);
                                                    clickPostIntent.putExtra("type", model.getType());
                                                    startActivity(clickPostIntent);
                                                }
                                            });

                                            holder.clickForVideo.setOnClickListener(new View.OnClickListener() {
                                                @Override
                                                public void onClick(View v) {
                                                    Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                    clickPostIntent.putExtra("PostKey", PostKey);
                                                    clickPostIntent.putExtra("type", model.getType());
                                                    startActivity(clickPostIntent);
                                                }
                                            });

                                            holder.postImage.setOnClickListener(new View.OnClickListener() {
                                                @Override
                                                public void onClick(View v) {
                                                    Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                    clickPostIntent.putExtra("PostKey", PostKey);
                                                    clickPostIntent.putExtra("type", model.getType());
                                                    startActivity(clickPostIntent);
                                                }
                                            });

                                            holder.commentPostButton.setOnClickListener(new View.OnClickListener() {
                                                @Override
                                                public void onClick(View v) {
                                                    SendUserToCommentActivity(PostKey);
                                                }
                                            });

                                            holder.likeButton.setOnClickListener(new View.OnClickListener() {
                                                @Override
                                                public void onClick(View v) {
                                                    likeChecker = true;
                                                    LikesRef.addValueEventListener(new ValueEventListener() {
                                                        @Override
                                                        public void onDataChange(DataSnapshot dataSnapshot) {
                                                            if (likeChecker.equals(true)) {
                                                                if (dataSnapshot.child(PostKey).hasChild(currentUserID)) {//Like existitzen bada
                                                                    LikesRef.child(PostKey).child(currentUserID).removeValue();//Ezabatu like-a
                                                                    likeChecker = false;

                                                                } else {//Ez bada like-a eman
                                                                    LikesRef.child(PostKey).child(currentUserID).setValue(true);
                                                                    likeChecker = false;
                                                                }
                                                            }
                                                        }

                                                        @Override
                                                        public void onCancelled(DatabaseError databaseError) {

                                                        }
                                                    });

                                                }
                                            });
                                        } else {
                                            holder.linearLayout.removeAllViewsInLayout();
                                            holder.linearLayout.setVisibility(View.GONE);
                                            holder.Layout_hide();
                                        }
                                    } else if (currentUserID.equals(uid)) {
                                        holder.time.setText(" " + model.getTime());
                                        holder.date.setText(" " + model.getDate());
                                        holder.description.setText(model.getStatus());

                                        if(model.getType().equals("video")){
                                            holder.postImage.setVisibility(View.GONE);
                                            holder.clickForVideo.setVisibility(View.VISIBLE);
                                        }else if(model.getType().equals("image")) {
                                            holder.clickForVideo.setVisibility(View.GONE);
                                            Picasso.get().load(model.getPostimage()).into(holder.postImage);
                                        }else if(model.getType().equals("text")){
                                            holder.postImage.setVisibility(View.GONE);
                                            holder.clickForVideo.setVisibility(View.GONE);
                                            holder.clickForText.setVisibility(View.VISIBLE);
                                            holder.description.setVisibility(View.GONE);
                                            holder.status.setText(model.getStatus());
                                        }

                                        UserRef.child(model.getUid()).addValueEventListener(new ValueEventListener() {
                                            @Override
                                            public void onDataChange(DataSnapshot dataSnapshot) {
                                                if(dataSnapshot.child("fullname").exists() && dataSnapshot.child("profileimage").exists()) {
                                                    holder.username.setText(dataSnapshot.child("fullname").getValue().toString());

                                                    Picasso.get().load(dataSnapshot.child("profileimage").getValue().toString()).into(holder.user_post_image);
                                                }

                                            }

                                            @Override
                                            public void onCancelled(DatabaseError databaseError) {

                                            }
                                        });

                                        holder.setLikeButtonStatus(PostKey);

                                        holder.user_post_image.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {

                                                if (currentUserID.equals(uid)) {
                                                    Intent ownProfileIntent = new Intent(MainActivity.this, ProfileActivity.class);
                                                    startActivity(ownProfileIntent);
                                                } else {
                                                    Intent clickProfileIntent = new Intent(MainActivity.this, PersonProfileActivity.class);
                                                    clickProfileIntent.putExtra("ProfileKey", uid);
                                                    startActivity(clickProfileIntent);
                                                }

                                            }
                                        });

                                        holder.clickForText.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {
                                                Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                clickPostIntent.putExtra("PostKey", PostKey);
                                                clickPostIntent.putExtra("type", model.getType());
                                                startActivity(clickPostIntent);
                                            }
                                        });

                                        holder.post_video.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {
                                                Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                clickPostIntent.putExtra("PostKey", PostKey);
                                                clickPostIntent.putExtra("type", model.getType());
                                                startActivity(clickPostIntent);
                                            }
                                        });

                                        holder.clickForVideo.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {
                                                Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                clickPostIntent.putExtra("PostKey", PostKey);
                                                clickPostIntent.putExtra("type", model.getType());
                                                startActivity(clickPostIntent);
                                            }
                                        });

                                        holder.postImage.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {
                                                Intent clickPostIntent = new Intent(MainActivity.this, ClickPostAcitivity.class);
                                                clickPostIntent.putExtra("PostKey", PostKey);
                                                clickPostIntent.putExtra("type", model.getType());
                                                startActivity(clickPostIntent);
                                            }
                                        });

                                        holder.commentPostButton.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {
                                                SendUserToCommentActivity(PostKey);
                                            }
                                        });

                                        holder.likeButton.setOnClickListener(new View.OnClickListener() {
                                            @Override
                                            public void onClick(View v) {
                                                likeChecker = true;
                                                LikesRef.addValueEventListener(new ValueEventListener() {
                                                    @Override
                                                    public void onDataChange(DataSnapshot dataSnapshot) {
                                                        if (likeChecker.equals(true)) {
                                                            if (dataSnapshot.child(PostKey).hasChild(currentUserID)) {//Like existitzen bada
                                                                LikesRef.child(PostKey).child(currentUserID).removeValue();//Ezabatu like-a
                                                                likeChecker = false;

                                                            } else {//Ez bada like-a eman
                                                                LikesRef.child(PostKey).child(currentUserID).setValue(true);
                                                                likeChecker = false;
                                                            }
                                                        }
                                                    }

                                                    @Override
                                                    public void onCancelled(DatabaseError databaseError) {

                                                    }
                                                });

                                            }
                                        });
                                    } else {

                                        holder.linearLayout.removeAllViewsInLayout();
                                        holder.linearLayout.setVisibility(View.GONE);
                                        holder.Layout_hide();
                                    }
                                }

                    @Override
                    public void onCancelled(DatabaseError databaseError) {

                    }
                });


            }

            @NonNull
            @Override
            public PostsViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                View view=LayoutInflater.from(parent.getContext()).inflate(R.layout.all_post_layout,parent,false);
                PostsViewHolder viewHolder=new PostsViewHolder(view);
                return viewHolder;
            }
        };
        postList.setAdapter(firebaseRecyclerAdapter);
        firebaseRecyclerAdapter.startListening();

    }


    public static class PostsViewHolder extends RecyclerView.ViewHolder{
        RelativeLayout.LayoutParams params;
        LinearLayout linearLayout, clickForVideo, clickForText;
        TextView username,date,time,description, displayNumberOfLikes, status;
        CircleImageView user_post_image;
        ImageView postImage;
        ImageButton likeButton, commentPostButton, post_video;
        int countLikes;
        String currentUserIds;
        DatabaseReference LikesRef;
        View mView;
        public PostsViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            //IMAGE//
            linearLayout = (LinearLayout) mView.findViewById(R.id.linear_layout);
            params = new RelativeLayout.LayoutParams(0, 0);
            username=mView.findViewById(R.id.post_profile_username);
            displayNumberOfLikes=mView.findViewById(R.id.number_of_likes);
            likeButton=mView.findViewById(R.id.like_button);
            commentPostButton=mView.findViewById(R.id.post_comments);
            date=mView.findViewById(R.id.date);
            time=mView.findViewById(R.id.time);
            description=mView.findViewById(R.id.post_description);
            postImage=mView.findViewById(R.id.post_image);
            user_post_image=mView.findViewById(R.id.post_profile_image);
            LikesRef= FirebaseDatabase.getInstance().getReference().child("Likes");
            currentUserIds = FirebaseAuth.getInstance().getCurrentUser().getUid();
            clickForVideo = mView.findViewById(R.id.click_for_video);
            clickForText = mView.findViewById(R.id.click_for_text);
            status = mView.findViewById(R.id.postText_status);
            post_video = mView.findViewById(R.id.post_video);

        }

        public void setLikeButtonStatus(final String postKey){
            LikesRef.addValueEventListener(new ValueEventListener() {
                @Override
                public void onDataChange(DataSnapshot dataSnapshot) {
                    if(dataSnapshot.child(postKey).hasChild(currentUserIds)){
                        countLikes = (int) dataSnapshot.child(postKey).getChildrenCount();
                        likeButton.setImageResource(R.drawable.like);
                        displayNumberOfLikes.setText(Integer.toString(countLikes));
                    }else{
                        countLikes = (int) dataSnapshot.child(postKey).getChildrenCount();
                        likeButton.setImageResource(R.drawable.dislike);
                        displayNumberOfLikes.setText(Integer.toString(countLikes));
                    }
                }

                @Override
                public void onCancelled(DatabaseError databaseError) {

                }
            });
        }

        void Layout_hide() {
            params.height = 0;
            //itemView.setLayoutParams(params);
            linearLayout.setLayoutParams(params);

        }
    }


    @Override
    protected void onStart() {
        super.onStart();
        FirebaseUser currentUser = mAuth.getCurrentUser();
        if(currentUser == null || currentUserID == null){
            SendUserToLoginActivity();
        }else{
            CheckUserExistence();
        }
    }

    private void CheckUserExistence() {
        final String current_user_id = mAuth.getCurrentUser().getUid();
        currentUserID = current_user_id;
        UserRef.addValueEventListener(new ValueEventListener() {
            @Override
            public void onDataChange(DataSnapshot dataSnapshot) {
                if(!dataSnapshot.child(currentUserID).hasChild("fullname")){
                    Toast.makeText(MainActivity.this, R.string.registration_finish, Toast.LENGTH_SHORT).show();
                    SendUserToSetUpActivity();
                }
                if(!dataSnapshot.child(currentUserID).hasChild("profileimage")){
                    Toast.makeText(MainActivity.this, R.string.registration_finish, Toast.LENGTH_SHORT).show();
                    SendUserToProfilePicActivity();
                }
            }

            @Override
            public void onCancelled(DatabaseError databaseError) {

            }
        });

    }


    private void SendUserToSetUpActivity() {
        Intent setupIntent = new Intent(MainActivity.this, SetUpActivity.class);
        setupIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(setupIntent);
        finish();
    }

    private void SendUserToProfilePicActivity() {
        Intent setupIntent = new Intent(MainActivity.this, ProfilePicActivity.class);
        setupIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(setupIntent);
        finish();
    }

    private  void SendUserToLoginActivity() {
        Intent loginIntent = new Intent(MainActivity.this, LoginActivity.class);
        loginIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(loginIntent);
        finish();
    }

    private void SendUserToPostActivity() {
        Intent postIntent = new Intent(MainActivity.this, PostActivity.class);
        startActivity(postIntent);
    }

    private void SendUserToSettingActivity() {
        Intent settingIntent = new Intent(MainActivity.this, SettingsActivity.class);
        startActivity(settingIntent);
    }

    private void SendUserToProfileActivity() {
        Intent profileIntent = new Intent(MainActivity.this, ProfileActivity.class);
        startActivity(profileIntent);
    }
    private void SendUserToFindFriendActivity() {
        Intent friendsearchIntent = new Intent(MainActivity.this, FindFriendsActivity.class);
        startActivity(friendsearchIntent);
    }

    private void SendUserToCommentActivity(String postKey) {
        Intent commentIntent = new Intent(MainActivity.this, CommentsActivity.class);
        commentIntent.putExtra("PostKey", postKey);
        startActivity(commentIntent);
    }
    private void SendUserToFriendRequestActivity() {
        Intent friendrequestIntent = new Intent(MainActivity.this, FriendRequestsActivity.class);
        startActivity(friendrequestIntent);
    }
    public void SendUserToFriendListActivity(){
        Intent friendListIntent = new Intent(MainActivity.this, FriendListActivity.class);
        startActivity(friendListIntent);
    }
    private void SendUserToChatActivity() {
        Intent chatIntent = new Intent(MainActivity.this, ChatMenuActivity.class);
        startActivity(chatIntent);
    }
    private void SendUserToMapActivity() {
        Intent mapIntent = new Intent(MainActivity.this, MapActivity.class);
        startActivity(mapIntent);
    }

    private void SendUserToBoulderActivity(){
        Intent boulderIntent = new Intent(MainActivity.this, ChooseBoulderAddActivity.class);
        startActivity(boulderIntent);
    }

    private void SendUserToFindBoulderActivity(){
        Intent boulderFindIntent = new Intent(MainActivity.this, FindBouldersActivity.class);
        startActivity(boulderFindIntent);
    }

    private void SendUserToToDoActivity(){
        Intent boulderFindIntent = new Intent(MainActivity.this, ToDoActivity.class);
        startActivity(boulderFindIntent);
    }

    private void SendUserToChallengeListActivity(){
        Intent challengeIntent = new Intent(MainActivity.this, ChallengesListActivity.class);
        startActivity(challengeIntent);
    }

    private void SendUserToAllChallengeListActivity(){
        Intent challengeIntent = new Intent(MainActivity.this, AllChallengeListActivity.class);
        startActivity(challengeIntent);
    }

    private void SendUserToLikeBoulderActivity(){
        Intent likeBoulderIntent = new Intent(MainActivity.this, LikeBouldersActivity.class);
        startActivity(likeBoulderIntent);
    }

    private void SendUserToGlobalRanking(){
        Intent rankingIntent = new Intent(MainActivity.this, GlobalRankingActivity.class);
        startActivity(rankingIntent);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu){
        getMenuInflater().inflate(R.menu.menu_todo, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        if(actionBarDrawerToggle.onOptionsItemSelected(item)){
            return true;
        }else{
            switch (item.getItemId()) {
                case R.id.nav_challenge:
                    SendUserToChallengeListActivity();
                    break;

                case R.id.nav_toDo:
                    SendUserToToDoActivity();
                    break;

                case R.id.nav_all_challenge:
                    SendUserToAllChallengeListActivity();
                    break;
            }
        }
        return super.onOptionsItemSelected(item);
    }

    private void UserMenuSelector(MenuItem item) {
        switch (item.getItemId()){
            case R.id.nav_post:
                SendUserToPostActivity();
                break;

            case R.id.nav_profile:
                SendUserToProfileActivity();
                break;

            case R.id.nav_maps:
                SendUserToMapActivity();
                break;

            case R.id.nav_boulder:
                SendUserToBoulderActivity();
                break;

            case R.id.nav_requests:
                SendUserToFriendRequestActivity();
                break;

            case R.id.nav_friends:
                SendUserToFriendListActivity();
                break;

            case R.id.nav_find_boulders:
                SendUserToFindBoulderActivity();
                break;

            case R.id.nav_global_rank:
                SendUserToGlobalRanking();
                break;

            case R.id.nav_find_friends:
                SendUserToFindFriendActivity();
                break;

            case R.id.nav_fav_boulders:
                SendUserToLikeBoulderActivity();
                break;

            case R.id.nav_message:
                SendUserToChatActivity();
                break;

            case R.id.nav_settings:
                SendUserToSettingActivity();
                break;

            case R.id.nav_logout:
                mAuth.signOut();
                SendUserToLoginActivity();
                break;

        }
    }




}
