package com.example.kurama.aprieta;

import android.app.ProgressDialog;
import android.content.Intent;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.AuthResult;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.auth.FirebaseUser;

public class RegisterActivity extends AppCompatActivity {

    private EditText UserEmail, UserPassword, UserConfirmPass;
    private Button CreateUser;
    private FirebaseAuth mAuth;
    private ProgressDialog loadingBar;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_register);

        mAuth = FirebaseAuth.getInstance();

        UserEmail = (EditText) findViewById(R.id.register_email);
        UserPassword = (EditText) findViewById(R.id.register_password);
        UserConfirmPass = (EditText) findViewById(R.id.register_confirm_password);
        CreateUser = (Button) findViewById(R.id.signin);
        loadingBar = new ProgressDialog(this);

        CreateUser.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                CreateNewAccount();
            }
        });
    }

    @Override
    protected void onStart() {
        super.onStart();
        FirebaseUser currentUser = mAuth.getCurrentUser();
        if(currentUser != null){
            SendUserToMainActivity();
        }
    }

    private void SendUserToMainActivity() {
        Intent mainIntent = new Intent(RegisterActivity.this, MainActivity.class);
        mainIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(mainIntent);
        finish();
    }

    private void CreateNewAccount() {
        String email = UserEmail.getText().toString();
        String password = UserPassword.getText().toString();
        String confirm = UserConfirmPass.getText().toString();

        if(TextUtils.isEmpty(email)){
            Toast.makeText(this,R.string.registration_email_hints, Toast.LENGTH_SHORT).show();
        }else if(TextUtils.isEmpty(password)){
            Toast.makeText(this,R.string.registration_password_hints, Toast.LENGTH_SHORT).show();
        }else if(TextUtils.isEmpty(confirm)){
            Toast.makeText(this,R.string.registration_password2_hints, Toast.LENGTH_SHORT).show();
        }else if(!password.equals(confirm)){
            Toast.makeText(this,R.string.registration_match_pass_noty, Toast.LENGTH_SHORT).show();
        }else{
            loadingBar.setTitle(R.string.registration_epnoty);
            loadingBar.show();
            loadingBar.setCanceledOnTouchOutside(true);

            mAuth.createUserWithEmailAndPassword(email, password).addOnCompleteListener(new OnCompleteListener<AuthResult>() {
                @Override
                public void onComplete(@NonNull Task<AuthResult> task) {
                    if(task.isSuccessful()){
                        Toast.makeText(RegisterActivity.this,R.string.registration_result_noty, Toast.LENGTH_SHORT).show();
                        loadingBar.dismiss();
                        SendUserToSetUpActivity();
                    }else{
                        String message = task.getException().getMessage();
                        Toast.makeText(RegisterActivity.this, "Error:"+message, Toast.LENGTH_SHORT).show();
                        loadingBar.dismiss();
                    }
                }
            });

        }
    }
    private void SendUserToSetUpActivity() {
        Intent setupIntent = new Intent(RegisterActivity.this, ProfilePicActivity.class);
        setupIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(setupIntent);
        finish();
    }
}
