package com.example.kurama.aprieta;

import android.app.ProgressDialog;
import android.content.Intent;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.Toolbar;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.Toast;

import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.ValueEventListener;
import com.google.firebase.storage.FirebaseStorage;
import com.google.firebase.storage.StorageReference;
import com.google.firebase.storage.UploadTask;
import com.squareup.picasso.Picasso;
import com.theartofdev.edmodo.cropper.CropImage;
import com.theartofdev.edmodo.cropper.CropImageView;

import java.util.HashMap;

import de.hdodenhof.circleimageview.CircleImageView;

public class SettingsActivity extends AppCompatActivity {

    private Uri ImageUri;
    private Toolbar mToolbar;
    private EditText username, fullname, status, country;
    private Button updateSettings;
    private ImageButton messageAdmin;
    private CircleImageView profileImage;

    private DatabaseReference SettingUserRef, UsersRef, adminRef;
    private FirebaseAuth mAuth;
    private String currentUserID;
    private StorageReference UserProfileImageRef;

    private ProgressDialog loadingBar;

    final static int Gallery_Pick = 1;
    private String myProfileImage;
    private int exists;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_settings);

        loadingBar = new ProgressDialog(this);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        SettingUserRef = FirebaseDatabase.getInstance().getReference().child("Users").child(currentUserID);
        UsersRef = FirebaseDatabase.getInstance().getReference().child("Users");
        adminRef = FirebaseDatabase.getInstance().getReference().child("Admin").child("MessagesWith");
        UserProfileImageRef = FirebaseStorage.getInstance().getReference().child("Profile Images");

        mToolbar =(Toolbar) findViewById(R.id.settings_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setTitle(R.string.account_settings_title);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        username = (EditText) findViewById(R.id.settings_username);
        fullname = (EditText) findViewById(R.id.settings_fullname);
        status = (EditText) findViewById(R.id.settings_status);
        country = (EditText) findViewById(R.id.settings_country);
        updateSettings = (Button) findViewById(R.id.settings_button);
        profileImage = (CircleImageView) findViewById(R.id.setting_image);
        messageAdmin = findViewById(R.id.messageForAdmin);
        exists = 0;

        messageAdmin.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                adminRef.child(currentUserID).child("chat").setValue("true");
                Intent clickProfileIntent = new Intent(SettingsActivity.this, ChatActivity.class);
                clickProfileIntent.putExtra("ProfileKey", "LiApsI6W5uVfOFBZdyqgRBpL9li1");
                startActivity(clickProfileIntent);
            }
        });

    SettingUserRef.addValueEventListener(new ValueEventListener() {
        @Override
        public void onDataChange(DataSnapshot dataSnapshot) {
            if(dataSnapshot.exists()){
                 myProfileImage = dataSnapshot.child("profileimage").getValue().toString();
                String myUserName = dataSnapshot.child("username").getValue().toString();
                String myFullName = dataSnapshot.child("fullname").getValue().toString();
                String myStatus = dataSnapshot.child("status").getValue().toString();
                String myCountry = dataSnapshot.child("country").getValue().toString();

                Picasso.get().load(myProfileImage).placeholder(R.drawable.profile).into(profileImage);
                username.setText(myUserName);
                fullname.setText(myFullName);
                status.setText(myStatus);
                country.setText(myCountry);



            }

        }

        @Override
        public void onCancelled(DatabaseError databaseError) {

        }
});

        updateSettings.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                ValidateAccountInfo();
            }
        });

        profileImage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openGallery();
            }
        });


    }


    @Override
    public void onActivityResult(int requestCode, int resultCode, Intent data){
        super.onActivityResult(resultCode,resultCode,data);

        if(requestCode==Gallery_Pick && resultCode==RESULT_OK && data!=null){
            ImageUri = data.getData();

            CropImage.activity(ImageUri)
                    .setGuidelines(CropImageView.Guidelines.ON)
                    .setAspectRatio(1, 1)
                    .start(this);

        }
        if(requestCode==CropImage.CROP_IMAGE_ACTIVITY_REQUEST_CODE)
        {
            CropImage.ActivityResult result = CropImage.getActivityResult(data);

            if(resultCode == RESULT_OK)
            {
                loadingBar.setTitle(R.string.loading_settings);
                loadingBar.show();
                loadingBar.setCanceledOnTouchOutside(true);

                Uri resultUri = result.getUri();

                StorageReference filePath = UserProfileImageRef.child(currentUserID + ".jpg");

                filePath.putFile(resultUri).addOnCompleteListener(new OnCompleteListener<UploadTask.TaskSnapshot>() {
                    @Override
                    public void onComplete(@NonNull final Task<UploadTask.TaskSnapshot> task)
                    {
                        if(task.isSuccessful())
                        {
                            final String downloadUrl = task.getResult().getDownloadUrl().toString();

                            SettingUserRef.child("profileimage").setValue(downloadUrl)
                                    .addOnCompleteListener(new OnCompleteListener<Void>() {
                                        @Override
                                        public void onComplete(@NonNull Task<Void> task)
                                        {
                                            if(task.isSuccessful())
                                            {

                                                Picasso.get().load(myProfileImage).placeholder(R.drawable.profile).into(profileImage);

                                                loadingBar.dismiss();

                                            }
                                            else
                                            {
                                                String message = task.getException().getMessage();
                                                Toast.makeText(SettingsActivity.this, "Error Occured: " + message, Toast.LENGTH_SHORT).show();
                                                loadingBar.dismiss();

                                            }
                                        }
                                    });


                        }
                    }
                });
            }
            else
            {
                Toast.makeText(this, "Error Occured: Image can not be cropped. Try Again.", Toast.LENGTH_SHORT).show();
                loadingBar.dismiss();
            }
        }
    }

    private void ValidateAccountInfo() {
        exists = 0;
        final String username = this.username.getText().toString();
        final String fullname = this.fullname.getText().toString();
        final String status = this.status.getText().toString();
        final String country = this.country.getText().toString();

        if(TextUtils.isEmpty(username)){
            Toast.makeText(this, R.string.fill_username_settings_noty, Toast.LENGTH_SHORT).show();
        }
        if(TextUtils.isEmpty(fullname)){
            Toast.makeText(this, R.string.fill_fullname_settings_noty, Toast.LENGTH_SHORT).show();
        }
        if(TextUtils.isEmpty(country)){
            Toast.makeText(this, R.string.fill_country_settings_noty, Toast.LENGTH_SHORT).show();
        }
        if(!TextUtils.isEmpty(username) && !TextUtils.isEmpty(country) && !TextUtils.isEmpty(fullname)){
            UsersRef.addListenerForSingleValueEvent(new ValueEventListener() {
                @Override
                public void onDataChange(DataSnapshot dataSnapshot) {
                    if(dataSnapshot.exists()){
                        for(DataSnapshot ds : dataSnapshot.getChildren()){
                            if(ds.hasChild("username")) {
                                if (ds.child("username").getValue().toString().equals(username)) {
                                    Toast.makeText(SettingsActivity.this, R.string.registration_setup_userExist, Toast.LENGTH_SHORT).show();
                                    exists++;
                                }
                            }

                        }
                        if(exists==0){
                            UpdateAccountInformation(username, fullname, status, country);

                        }
                    }
                }

                @Override
                public void onCancelled(DatabaseError databaseError) {

                }
            });

        }

    }

    private void UpdateAccountInformation(String username, String fullname, String status, String country) {
        HashMap userMap = new HashMap();
        userMap.put("username", username);
        userMap.put("fullname", fullname);
        userMap.put("status", status);
        userMap.put("country", country);

        SettingUserRef.updateChildren(userMap).addOnCompleteListener(new OnCompleteListener() {
            @Override
            public void onComplete(@NonNull Task task) {
                if(task.isSuccessful()){
                    SendUserToMainActivity();
                    Toast.makeText(SettingsActivity.this, R.string.settings_save_noty, Toast.LENGTH_SHORT).show();

                }else{
                    Toast.makeText(SettingsActivity.this, "Error...", Toast.LENGTH_SHORT).show();

                }
            }
        });



    }

    private void openGallery() {
        Intent galleryIntent = new Intent();
        galleryIntent.setAction(Intent.ACTION_GET_CONTENT);
        galleryIntent.setType("image/*");
        startActivityForResult(galleryIntent, Gallery_Pick);
    }

    private void SendUserToMainActivity() {
        Intent mainIntent = new Intent(SettingsActivity.this, MainActivity.class);
        mainIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | Intent.FLAG_ACTIVITY_CLEAR_TASK);
        startActivity(mainIntent);
        finish();
    }
}
