package com.example.kurama.aprieta;

import android.content.Intent;
import android.graphics.Canvas;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.support.v7.widget.helper.ItemTouchHelper;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.firebase.ui.database.FirebaseRecyclerAdapter;
import com.firebase.ui.database.FirebaseRecyclerOptions;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.FirebaseAuth;
import com.google.firebase.database.DataSnapshot;
import com.google.firebase.database.DatabaseError;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.google.firebase.database.Query;
import com.google.firebase.database.ValueEventListener;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;

public class ToDoActivity extends AppCompatActivity {
    private Toolbar mToolbar;

    private RecyclerView bouldersList;

    private FirebaseAuth mAuth;
    private DatabaseReference UserRef;
    private DatabaseReference PostRef, allBoulderDatabaseRef;
    private String currentUserID;

    @Override
    public boolean onSupportNavigateUp() {
        onBackPressed();
        return true;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        finish();
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_to_do);

        mAuth = FirebaseAuth.getInstance();
        currentUserID = mAuth.getCurrentUser().getUid();
        allBoulderDatabaseRef = FirebaseDatabase.getInstance().getReference().child("Boulders");
        UserRef = FirebaseDatabase.getInstance().getReference().child("Users").child(currentUserID);

        mToolbar = (Toolbar) findViewById(R.id.toDoBoulders_toolbar);
        setSupportActionBar(mToolbar);
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setDisplayShowHomeEnabled(true);
        getSupportActionBar().setTitle(R.string.toDoBoulders_done);

        bouldersList = (RecyclerView) findViewById(R.id.toDoBoulders_list);
        bouldersList.setHasFixedSize(true);
        bouldersList.setLayoutManager(new LinearLayoutManager(this));


        searchAllBoulders();
    }

    private void searchAllBoulders() {
         Query searchBoulders = allBoulderDatabaseRef.orderByChild("name");

         FirebaseRecyclerOptions<FindBoulders> options = new FirebaseRecyclerOptions.Builder<FindBoulders>().setQuery(searchBoulders, FindBoulders.class).build();
         final FirebaseRecyclerAdapter<FindBoulders, ToDoActivity.FindBouldersViewHolder> firebaseRecyclerAdapter = new FirebaseRecyclerAdapter<FindBoulders, ToDoActivity.FindBouldersViewHolder>(options) {
             @Override
             protected void onBindViewHolder(@NonNull final ToDoActivity.FindBouldersViewHolder holder, int position, @NonNull final FindBoulders model) {
                 final String BoulderKey = getRef(position).getKey();
                 UserRef.child("toDoBoulders").addValueEventListener(new ValueEventListener() {
                     @Override
                     public void onDataChange(DataSnapshot dataSnapshot) {

                         if(dataSnapshot.exists()) {
                             if (dataSnapshot.child(BoulderKey).exists()) {

                                 holder.name.setText(model.getName());
                                 holder.location.setText(model.getLocation());
                                 holder.grade.setText(model.getGrade());
                                 holder.mView.setOnClickListener(new View.OnClickListener() {
                                     @Override
                                     public void onClick(View v) {
                                         Intent boulderProfileIntent = new Intent(ToDoActivity.this, BoulderProfileActivity.class);
                                         boulderProfileIntent.putExtra("BoulderKey", BoulderKey);
                                         startActivity(boulderProfileIntent);
                                         finish();

                                     }
                                 });
                             }else{
                                 holder.linearLayout.removeAllViewsInLayout();
                                 holder.linearLayout.setVisibility(View.GONE);
                                 holder.Layout_hide();
                             }
                         }else{
                             holder.linearLayout.removeAllViewsInLayout();
                             holder.linearLayout.setVisibility(View.GONE);
                             holder.Layout_hide();
                         }
                     }

                     @Override
                     public void onCancelled(DatabaseError databaseError) {

                     }
                 });



             }

             @NonNull
             @Override
             public ToDoActivity.FindBouldersViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
                 View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.all_boulder_display_layout, parent, false);
                 ToDoActivity.FindBouldersViewHolder viewHolder = new ToDoActivity.FindBouldersViewHolder(view);
                 return viewHolder;
             }
         };



        bouldersList.setAdapter(firebaseRecyclerAdapter);
        final SwipeController swipeController = new SwipeController(new SwipeControllerActions(){
            @Override
            public void onRightClicked(int position) {
                UserRef.child("toDoBoulders").child(firebaseRecyclerAdapter.getRef(position).getKey()).removeValue();
                searchAllBoulders();
            }

            @Override
            public void onLeftClicked(final int position) {
                Calendar date = Calendar.getInstance();
                SimpleDateFormat currentDate = new SimpleDateFormat("yyyy-MM-dd");
                String saveCurrentDate = currentDate.format(date.getTime());

                HashMap addDoneBoulders = new HashMap();
                addDoneBoulders.put(firebaseRecyclerAdapter.getRef(position).getKey(), firebaseRecyclerAdapter.getRef(position).getKey());

                HashMap dateDoneBoulder = new HashMap();
                dateDoneBoulder.put("date", saveCurrentDate);

                UserRef.addListenerForSingleValueEvent(new ValueEventListener() {
                    @Override
                    public void onDataChange( final DataSnapshot dataSnapshot) {
                        allBoulderDatabaseRef.child(firebaseRecyclerAdapter.getRef(position).getKey()).addListenerForSingleValueEvent(new ValueEventListener()  {
                            @Override
                            public void onDataChange(DataSnapshot dataSnapshot1) {
                                int m = Integer.parseInt(dataSnapshot1.child("height").getValue().toString());
                                int actualM = Integer.parseInt(dataSnapshot.child("metrosTotal").getValue().toString());
                                UserRef.child("metrosTotal").setValue(String.valueOf(m+actualM));
                            }
                            @Override
                            public void onCancelled(DatabaseError databaseError) {}
                        });
                    }
                    @Override
                    public void onCancelled(DatabaseError databaseError) {}
                });
                UserRef.child("doneBoulders").updateChildren(addDoneBoulders).addOnCompleteListener(new OnCompleteListener() {
                    @Override
                    public void onComplete(@NonNull Task task) {
                        if(task.isSuccessful()){
                            Toast.makeText(ToDoActivity.this, R.string.toDoBoulders_done, Toast.LENGTH_SHORT).show();
                        }
                    }
                });
                UserRef.child("doneBoulders").child(firebaseRecyclerAdapter.getRef(position).getKey()).updateChildren(dateDoneBoulder);
                UserRef.child("toDoBoulders").child(firebaseRecyclerAdapter.getRef(position).getKey()).removeValue();
                searchAllBoulders();
            }
        });
        ItemTouchHelper itemTouchhelper = new ItemTouchHelper(swipeController);
        itemTouchhelper.attachToRecyclerView(bouldersList);
        bouldersList.addItemDecoration(new RecyclerView.ItemDecoration() {
            @Override
            public void onDraw(Canvas c, RecyclerView parent, RecyclerView.State state) {
                swipeController.onDraw(c);
            }
        });
        firebaseRecyclerAdapter.startListening();



    }

    public static class FindBouldersViewHolder extends RecyclerView.ViewHolder{
        RelativeLayout.LayoutParams params;
        LinearLayout linearLayout;
        TextView name, location, grade;
        View mView;
        public FindBouldersViewHolder(View itemView) {
            super(itemView);
            mView = itemView;
            params = new RelativeLayout.LayoutParams(0, 0);
            linearLayout = (LinearLayout) mView.findViewById(R.id.boulderList);
            name=mView.findViewById(R.id.all_boulder_name);
            location=mView.findViewById(R.id.all_boulder_location);
            grade=mView.findViewById(R.id.all_grade);
        }


        public void Layout_hide() {
            params.height = 0;
            //itemView.setLayoutParams(params); //This One.
            linearLayout.setLayoutParams(params);   //Or This one.
        }
        public void Layout_show() {
            params = new RelativeLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
            //itemView.setLayoutParams(params); //This One.
            linearLayout.setLayoutParams(params);   //Or This one.
        }
    }

}
